<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://themeforest.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Fc
 * @subpackage Fc/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Fc
 * @subpackage Fc/public
 * @author     Kamleshyadav <support@pixelnx.com>
 */
class Fc_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		/**
		 * Create Shortcode 
		 */
		add_shortcode( 'fc-bmi-cal', array( $this,'fc_bmi_calculator_short' ) );
		add_shortcode( 'fc-water-intake', array( $this,'fc_water_intake_short' ) );
		add_shortcode( 'fc-calories-calculator', array( $this,'fc_calories_cal_short' ) );
		add_shortcode( 'fc-hf-quote', array( $this, 'fc_health_quotes' ) );
		add_shortcode( 'fc-walking-test', array( $this, 'walking_test' ) );
		add_shortcode( 'fc-blood-type', array( $this, 'blood_type_calculator' ) );
		add_shortcode( 'fc-dietchart', array( $this, 'fc_diet_chart' ) );
		add_shortcode( 'social_share', array( $this,'fc_page_template' ) );
		add_action( 'wp_footer', array( $this, 'fc_chatbot_display' ) );
		add_action( 'wp_footer', array( $this, 'fc_custom_css' ), 9999 );
		
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Fc_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Fc_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_register_style('plugin-fonts', plugin_dir_url( __FILE__ ) . 'css/fonts.css', array(), $this->version, 'all' );
		
		wp_register_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/fc-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Fc_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Fc_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_register_script('apexcharts', plugin_dir_url( __FILE__ ) . 'js/apexcharts.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script('jspdf', plugin_dir_url( __FILE__ ) . 'js/jspdf.min.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script('html2canvas', plugin_dir_url( __FILE__ ) . 'js/html2canvas.min.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script('chart-plugin', plugin_dir_url( __FILE__ ) . 'js/chart-controls.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/fc-public.js', array( 'jquery' ), $this->version, false );
		
		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/fc-public.js', array( 'jquery' ), $this->version, false );
		
		wp_localize_script($this->plugin_name, 'fc_ajax_path', array(
			'url' => admin_url('admin-ajax.php'),
			'admin_url' => admin_url(),
			'site_url' => home_url(),
			)
		);
	}
	/**
	 * BMI Calculator
	 */
	public function fc_bmi_calculator_short(){
	    wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );

		
		$result = $bmidata = $heading = $bmi_sw = $bfp_sw = $bodyfat_sw = $iweight_sw = '';
		$bmidata = get_option('fc_bmidata');
		if(!empty($bmidata['heading'])){
			$heading = $bmidata['heading'];
		}
		if(!empty($bmidata['bmi_sw'])){
			$bmi_sw = $bmidata['bmi_sw'];
		}
		if(!empty($bmidata['bmi_bfp_sw'])){
			$bfp_sw = $bmidata['bmi_bfp_sw'];
		}
		if(!empty($bmidata['bmi_bodyfat_sw'])){
			$bodyfat_sw = $bmidata['bmi_bodyfat_sw'];
		}
		if(!empty($bmidata['bmi_iweight_sw'])){
			$iweight_sw = $bmidata['bmi_iweight_sw'];
		}
		
		if(!empty($bmidata['bmi_iweight_sw'])){
			$iweight_sw = $bmidata['bmi_iweight_sw'];
		}
		$bmi_columnsec_sw = $columnsecenable = '';
		if(!empty($bmidata['bmi_columnsec_sw'])){
			$bmi_columnsec_sw = $bmidata['bmi_columnsec_sw'];
			if($bmi_columnsec_sw == 'on'){
				$columnsecenable = esc_attr__('fc-one-col','fc');
			}
			else{
				$columnsecenable = esc_attr__(' ','fc');
			}
		}
		
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-public-display.php';
		return $result;
	}
	public function fc_water_intake_short(){
		wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
        
		$heading = $wicdata = '';
		$wicdata = get_option('fc_wicdata');
		if(!empty($wicdata['heading'])){
			$heading = $wicdata['heading'];
		}
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-public-waterintake-display.php';
		return $result;
	}
	public function fc_calories_cal_short(){
	    wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
		
		$heading = $ccdata = '';
		$ccdata = get_option('fc_scc');
		if(!empty($ccdata['heading'])){
			$heading = $ccdata['heading'];
		}
		$calorie_columnsec = $colsecenable = '';
		if(!empty($ccdata['calorie_columnsec'])){
			$calorie_columnsec = $ccdata['calorie_columnsec'];
			if($calorie_columnsec == 'on'){
				$colsecenable = esc_attr__('fc-one-col','fc');
			}
			else{
				$colsecenable = esc_attr__(' ','fc');
			}
		}
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-public-caloriescal-display.php';
		return $result;
	}	
	
	// Fc 6 minute walking test
	public function walking_test(){
	    wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
	    
	    $wtdata = '';
		$wtdata = get_option('fc_wtdata');
	    $wt_columnsec = $colsecenable = '';
		if(!empty($wtdata['wt_column'])){
			$wt_columnsec = $wtdata['wt_column'];
			if($wt_columnsec == 'on'){
				$colsecenable = esc_attr__('fc-one-col','fc');
			}
			else{
				$colsecenable = esc_attr__(' ','fc');
			}
		}
	    
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-walking-test-display.php';
		return $result;
	}
	
	// Fc Blood Type
	public function blood_type_calculator(){
	    wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
        
        $btdata = '';
		$btdata = get_option('fc_btdata');
	    $bt_columnsec = $colsecenable = '';
		if(!empty($btdata['bt_column'])){
			$bt_columnsec = $btdata['bt_column'];
			if($bt_columnsec == 'on'){
				$colsecenable = esc_attr__('fc-one-col','fc');
			}
			else{
				$colsecenable = esc_attr__(' ','fc');
			}
		}
	    
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-blood-type-display.php';
		return $result;
	}
	
	// fc diet chart Shortcode
	public function fc_diet_chart(){
		wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
		$result = '';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-diet-chart-display.php';
		return $result;
	}
	
	// fc health and fitness quotes
	public function fc_health_quotes(){
		wp_enqueue_style( 'plugin-fonts' );
        wp_enqueue_style( 'fc' );
        wp_enqueue_script( 'apexcharts' );
        wp_enqueue_script( 'chart-plugin' );
        wp_enqueue_script( 'fc' );
        wp_enqueue_script( 'jspdf' );
        wp_enqueue_script( 'html2canvas' );
		
		$quotes = array(
            "Take care of your body. It's the only place you have to live.", "To enjoy the glow of good health, you must exercise.", "Physical fitness is not only one of the most important keys to a healthy body, it is the basis of dynamic and creative intellectual activity.", "Reading is to the mind what exercise is to the body.", "The purpose of training is to tighten up the slack, toughen the body, and polish the spirit.", "Fitness is not about being better than someone else... It's about being better than you used to be.", "For me, fitness is not just about hitting the gym; it is also about an inner happiness and an overall well-being.", "I'm not in the best shape, but I want to prove to myself I can do something that seems insurmountable and inspire others by showing them no matter where they are in their fitness goals, they can do it, too.", "Time and health are two precious assets that we don't recognize and appreciate until they have been depleted.", "The human body is the best picture of the human soul.", "The reason I exercise is for the quality of life I enjoy.", "Walking is the best possible exercise. Habituate yourself to walk very far.", "In fitness, there are no short cuts. It involves immense discipline and hard work.", "The mind is the most important part of achieving any fitness goal. Mental change always comes before physical change.", "A lot of people are afraid of heights. Not me, I'm afraid of widths.", "A muscle is like a car. If you want it to run well early in the morning, you have to warm it up.", "Exercise to stimulate, not to annihilate. The world wasn't formed in a day, and neither were we. Set small goals and build upon them.", "True enjoyment comes from activity of the mind and exercise of the body; the two are ever united.", "Fitness starts at home. What you eat is what you will look, just as what you sow is what you reap. Eat good food: eat fruits, vegetables, healthy grains, and don't go for sweet and trite food.", "People talk about physical fitness, but mental health is equally important. I see people suffering, and their families feel a sense of shame about it, which doesn't help. One needs support and understanding. I am now working on an initiative to create awareness about anxiety and depression and help people.", "The typical response from people when I tell them I'm diabetic is, 'Oh, I'm sorry to hear that.' You know, I'm not. I'm a better athlete because of diabetes rather than despite it. I'm more aware of my training, my fitness and more aware of nutrition. I'm more proactive about my health.", "Health is the thing that makes you feel that now is the best time of the year.", "I've always believed fitness is an entry point to help you build that happier, healthier life. When your health is strong, you're capable of taking risks. You'll feel more confident to ask for the promotion. You'll have more energy to be a better mom. You'll feel more deserving of love.", "Bodybuilding is much like any other sport. To be successful, you must dedicate yourself 100% to your training, diet and mental approach.", "You can always improve your fitness if you keep training.", "Swimming is normal for me. I'm relaxed. I'm comfortable, and I know my surroundings. It's my home.", "Exercise should be regarded as tribute to the heart.", "Leave all the afternoon for exercise and recreation, which are as necessary as reading. I will rather say more necessary because health is worth more than learning.", "Fitness is not an option. It's part of my job.", "The value and utility of any experiment are determined by the fitness of the material to the purpose for which it is used, and thus in the case before us it cannot be immaterial what plants are subjected to experiment and in what manner such experiment is conducted.", "If I don't feel confident about my body, I'm not going to sit at home and feel sorry for myself and not do something about it. It's all about taking action and not being lazy. So you do the work, whether it's fitness or whatever. It's about getting up, motivating yourself and just doing it.", "Exercise is amazing, from the inside out. I feel so alive and have more energy.", "Your body is the church where Nature asks to be reverenced.", "You need to put what you learn into practice and do it over and over again until it's a habit. I always say, 'Seeing is not believing. Doing is believing.' There is a lot to learn about fitness, nutrition and emotions, but once you do, you can master them instead of them mastering you.", "If we could give every individual the right amount of nourishment and exercise, not too little and not too much, we would have found the safest way to health.", "My fitness journey will be a lifelong journey.", "Our growing softness, our increasing lack of physical fitness, is a menace to our security.", "No one's ever achieved financial fitness with a January resolution that's abandoned by February.", "I am not a fitness freak, but I do my regular exercises.", "I think fitness is important. I think a healthy lifestyle is important. I think putting positive energy out there is important and just staying connected with the people.", "Health is the vital principle of bliss, and exercise, of health.", "In my judgment, physical fitness is basic to all forms of excellence and to a strong, confident nation.", "When the child begins to think and to make use of the written language to express his rudimentary thinking, he is ready for elementary work; and this fitness is a question not of age or other incidental circumstance but of mental maturity.", "I believe that fitness needs to come from within you. You need to respect your body. Only then will you have the zeal to maintain it. For me, keeping fit is a part of my lifestyle.", "I do a one-hour workout called Drenched, a cardio-boxing fitness routine, Monday through Friday. There are usually between twenty-five and fifty people there - everyone from stay-at-home moms and professional martial artists to teenagers and seniors. They play great dance music. When I can, I take two classes back-to-back.", "The torch relay is an excellent embodiment of all that the Olympic Games have come to symbolise - a celebration of the human spirit. Personally to me, it represents striving to be the best in whatever we do, never giving up despite the odds, and a commitment to health and fitness.", "In the midst of these hard times it is our good health and good sleep that are enjoyable.", "Fitness is a luxury when you are busy!", "You think aerobics is not a cool sport? I think you are wrong. It requires amazing discipline - flexibility, fitness, knowledge. And you have to do it with a big smile on your face. Also, I once performed in front of 10,000 screaming women. I tell you something, I'd rather do that than kick a ball around in front of a few men.", "Resting for me is fitness training.", "Jogging is very beneficial. It's good for your legs and your feet. It's also very good for the ground. If makes it feel needed.", "We wanted Nike to be the world's best sports and fitness company. Once you say that, you have a focus. You don't end up making wing tips or sponsoring the next Rolling Stones world tour.", "Guided only by their feeling for symmetry, simplicity, and generality, and an indefinable sense of the fitness of things, creative mathematicians now, as in the past, are inspired by the art of mathematics rather than by any prospect of ultimate usefulness.", "You must also give mental and physical fitness priority.", "If it weren't for the fact that the TV set and the refrigerator are so far apart, some of us wouldn't get any exercise at all.", "The only way for a rich man to be healthy is by exercise and abstinence, to live as if he were poor.", "Doing nothing would stress me out. So I am still pretty much active practicing judo with my friends, who are former judo athletes, to maintain our fitness as well as the friendships among us. In my spare time, I usually go jogging around the Gelora Bung Karno stadium or head to the gym.", "You can't be fat and fast, too; so lift, run, diet and work.", "I don't smoke, don't drink much, and go to the gym five times a week. I live a healthy lifestyle and feel great. I can run a marathon, you know.", "It's so easy to lose your fitness and so hard to gain it back.", "Developing a diet that is healthful, balanced, and appropriate for your particular caloric needs is easy enough and is absolutely critical to establishing a healthful lifestyle that incorporates proper nutrition, adequate fitness, and mental resilience.", "Cycling keeps me lean and I need to stay in shape, especially as I still like eating chocolate and ice-cream! I like to go mountain biking too. Running is also good; it's what we were designed to do as humans, so it comes naturally.", "I've spent half my life in gyms, if not more, and I love physical fitness and health; couple that with the fact that I love for people to be healthy, whether it's mentally, physically, or emotionally, and it's just a great opportunity for me to do something I love and have an impact on people's health.", "My own preferred fitness regime is to use my bicycle.", "People need to have clear goals about why they are exercising, and they should consult a fitness expert to find out what kind of exercise is suitable.", "I look at fitness as a necessity in the same way as how you drink water, eat food, one should look at fitness in a dedicated way. People will look fresh and happy. If you are happy, you in a way look fit.", "So I've broadened the fitness concept to make it one of moderation and balance.", "Sport is not just about entertainment. It is equally about winning and losing, pooling and galvanising the energy of the youth, upgrading people's physical fitness and mental prowess.", "Flexibility is crucial to my fitness. Incorporating a good warm-up and cool-down into every session decreases my chances of injury. I use both dynamic and static stretching in my training. I've starting doing a few yoga sessions which incorporates muscle strength and flexibility.", "The first time I see a jogger smiling, I'll consider it.", "Exercise is the chief source of improvement in our faculties.", "The fitness of the pupil is shown in his love for the acquisition of knowledge, his willingness to receive instruction, his reverence for learned and virtuous men, his attendance upon the teacher, and his execution of orders.", "My job is to be fit and I'm really blessed that I get to go and work out and live a really healthy lifestyle.", "It's challenging, but you have to at least try to eat right and exercise.", "Tactics, fitness, stroke ability, adaptability, experience, and sportsmanship are all necessary for winning.", "No one ceases to be a man, no one forfeits his rights to civilization merely by being more or less uncultured, and since the Filipino is regarded as a fit citizen when he is asked to pay taxes or shed his blood to defend the fatherland, why must this fitness be denied him when the question arises of granting him some right?", "Promoting healthy lifestyles and encouraging fitness are so important for our children's development and reducing the nation's epidemic of childhood obesity.", "As a longtime practitioner of yoga and a person who's been involved in physical fitness my whole life, I can tell you, yoga helps you achieve altered states of consciousness. It is not just stretching. The only way you can say that it's stretching is if you haven't done it, or that you haven't done it rigorously for a long period of time.", "I have never taken any exercise, except sleeping and resting, and I never intend to take any.", "I recommend that people try new stuff or take new fitness classes all the time. It's important to mix up your routine, not only for your body, but also for your mental state.", "Fitness needs to be perceived as fun and games or we subconsciously avoid it.", "For whatever reason, maybe it's because of my story, but people associate Livestrong with exercise and physical fitness, health and lifestyle choices like that.", "You can be in excellent physical shape, with low cholesterol, a healthy body weight and good overall physical fitness - but that doesn't necessarily mean you're healthy.", "I think I have just evolved as a person, as a human being. I like fitness. It's an important part of my everyday life, and I enjoy and endorse a healthy lifestyle.", "Don't get hung up on the size. If you feel bad about yourself because a 12 is what fits, take a Sharpie, and write '6' on the label.", "I have long recognized a link between fitness and mental health and I think we need to encourage young people to take part in sports and team activities because we know it has such positive results.", "Oh, and once, when I was in the Marines, I got a perfect score on my physical fitness test.", "If you ask me about my success story, the secret is I know when to pull myself back. I don't overexpose myself; I give proper gaps whenever I can. I do not over spend myself, I keep myself busy in lot of activities. I really work hard; I work harder than others, by focussing on my fitness level and studying music.", "It's been a long road back to health and fitness for me. I am just glad to have been given the opportunity to do what I love most.", "All we're trying to do is change how people think about fitness. And build Under Armour into the biggest brand in the entire land.", "My weight fluctuates depending on my mood and my current devotion to my fitness routine.", "Never hurry. Take plenty of exercise. Always be cheerful. Take all the sleep you need. You may expect to be well.", "When you're singing, you're using extra muscles, and it requires a lot of exercise and breathing. You can't do that if you're a sissy. If I have any fitness advice for people, I'd tell them to sing more. It's good therapy, too.", "When you get into the final week of the Tour de France, it becomes a different kind of race. As the distance and the fatigue really tell, that is when it becomes a proper test of everyone's fitness.", "Almost 70 per cent of your fitness battle is won the day you realise what your body needs and when. I've made my own diets, and I decide for myself what works for me.", "If someone thinks, 'I'll spend the off season working on my fitness and I'll come back a better cricketer,' I don't think that's enough. You need to spend a lot of time working on your skills and honing your skills.", "Ultimately, I'm in the fitness industry. But, I've branched out from there quite a bit. I began doing consulting on writing and getting published in magazines in about 2011. Right around that time, I started doing some angel investing and looking to grow my skills and general experience outside of that.", "I can jog, but I can't run. That's hard for me. I like the fact that I can jog for fitness, but to me there's a huge difference between jogging and running.", "I didn't have the same fitness or ability as the other girls, so I had to beat them with my mind.", "We are involved in youth testing internationally. We want to try to prove without a shadow of a doubt the relationship between physical fitness and health, not just physical fitness and ability to perform.", "Number one, like yourself. Number two, you have to eat healthy. And number three, you've got to squeeze your buns. That's my formula.", "A feeble body weakens the mind.", "Practice puts brains in your muscles.", "Health and fitness is who I am. It's what I do.", "Fitness is important, but the most important thing is how you adapt and the way you feel physically. To adapt to a new position. To try to change your game.", "Regularity in the hours of rising and retiring, perseverance in exercise, adaptation of dress to the variations of climate, simple and nutritious aliment, and temperance in all things are necessary branches of the regimen of health.", "I attend to my fitness. I go the gym every day and try to maintain my physical fitness; without that, it is tough to take challenges on the chess board.", "My wife and I work out together almost every day. It's just a great way to spend time together. We're going to run a marathon together later this year, and that's one more goal that we'll accomplish as husband and wife.", "If a man achieves victory over this body, who in the world can exercise power over him? He who rules himself rules over the whole world.", "I think exercise tests us in so many ways, our skills, our hearts, our ability to bounce back after setbacks. This is the inner beauty of sports and competition, and it can serve us all well as adult athletes.", "There's a lot of people in this world who spend so much time watching their health that they haven't the time to enjoy it.", "I like exercise. I like a healthy body.", "A life coach does for the rest of your life what a personal trainer does for your health and fitness.", "You can't get rid of it with exercise alone. You can do the most vigorous exercise and only burn up 300 calories in an hour. If you've got fat on your body, the exercise firms and tones the muscles. But when you use that tape measure, what makes it bigger? It's the fat!", "A runner must run with dreams in his heart, not money in his pocket.", "On the tennis court, one needs a cool temperament, tremendous ball sense, reflexes, speed, hand-eye co-ordination, power, timing and peak physical fitness. Off the court, the player and support team need skills in planning, execution, travel, an ability to raise funds when needed, and several other talents.", "You can be the most beautiful person on Earth, and if you don't have a fitness or diet routine, you won't be beautiful.", "Here's what I tell anybody and this is what I believe. The greatest gift we have is the gift of life. We understand that. That comes from our Creator. We're given a body. Now you may not like it, but you can maximize that body the best it can be maximized.", "Clearly, society has a tremendous stake in insisting on a woman's natural fitness for the career of mother: the alternatives are all too expensive.", "I think it's more important to be fit so that you can be healthy and enjoy activities than it is to have a good body.", "And I believe that the best buy in public health today must be a combination of regular physical exercise and a healthy diet.", "I love fitness, yoga. I love fashion. On the weekends, I try to relax. I have pretty crazy weeks. I like spas and nice dinners. I'm not much of a club person. I like to hang on the beach in Malibu.", "Fitness, defending, the mental stuff - those were all weaknesses of mine. And I turned those into strengths.", "A drunkard in the gutter is just where he ought to be, according to the fitness and tendency of things. Nature has set upon him the process of decline and dissolution by which she removes things which have survived their usefulness.", "Muscles come and go; flab lasts.", "Family involvement is a valuable thing and playing together actively can be the '90s version of it. Instead of just watching, you can do it together... something we don't spend enough time on. We can motivate and excite each other about fitness.", "I like to embrace natural beauty. I try to get at least 8 hours of sleep, drinking a lot of water and exercising.", "Fitness is very important to me because it helps give me a routine when I travel. It gives me one hour of 'me' time and passes the time when I'm lonely. Living with scoliosis serves as a constant reminder to keep my core and back strong. If I get lazy, I feel it in my back first.", "Women have fought so long and hard for our rights and equality, and now all our attention is put on being a size 0.", "I try and groom myself, be it through fitness or dance.", "I try to come at fitness and nutrition from a perspective of gentleness and what will make me feel good afterwards. I try to stay out of the mindset of needing to fix myself. I do whatever seems fun to me.", "I feel if I'm healthy and happy, I look good. With a good mixture of fitness and healthy food I always feel great!", "My mother was a P.E. teacher, and she was kind of a fanatic about fitness and nutrition growing up, so it was ingrained in me at a young age. As I get older, I'm finding out it's not about getting all buffed up and looking good. It's more about staying healthy and flexible.", "Training is such a vital part of preparation for a game, you really do train to play. It tops up your ability, like sharpening a carving knife. You can get away with not doing it for a while, as long as you have reached a certain standard of fitness.", "Exercise is done against one's wishes and maintained only because the alternative is worse.", "Parentage is a very important profession, but no test of fitness for it is ever imposed in the interest of the children.", "I've exercised with women so thin that buzzards followed them to their cars.", "Exercise is labor without weariness.", "I wanted to get really fit. I wanted to lose some weight. So I've been doing Pilates and yoga, trying to lean out my body so I won't be bulky.", "I suffer panic attacks which has made me really conscious about my fitness and I have become addicted to jogging. It might sound odd but a lot of good has come out of it. My fans send letters saying they have taken up jogging because I do it.", "I have a tremendous passion for fitness, I love challenges and I am a very driven guy.", "I am pleased with the fitness that I have.", "I think if you exercise, your state of mind - my state of mind - is usually more at ease, ready for more mental challenges. Once I get the physical stuff out of the way it always seems like I have more calmness and better self-esteem.", "Linguistics is a good way of defining the culture of a brand. The vocabulary used by sports and lifestyle brands - running, fitness, training, motorsports - is all about functionality, whereas the vocabulary of the luxury business - handbags, ready-to-wear - is all about the product.", "In terms of fitness and battling through cancer, exercise helps you stay strong physically and mentally.", "For exercise, I now run with my chocolate Lab puppy, Oscar.", "My Daddy liked physical fitness and wanted me to be a prizefighter.", "Our children are obese, either have or being threatened by diabetes, high blood pressure, high cholesterol, and not socially adjusting properly to others because of a lack of fitness.", "It takes about four days of virtuous living to create a little weight loss. That also happens to be the time required to get used to eating less. In other words, if you can get past day three of a fitness regimen, things improve.", "For years, I always thought it was hilarious that I was this fitness guru, because fitness was just a tool I utilized to help people improve their confidence. For me, it's never been about fitness. It's always been about helping to empower people.", "I'm quite into fitness, and I have a fantastic personal trainer who knows me, knows my body, knows when to push me, and knows when not to push me. She doesn't make me do 20 burpees in a row and instead focuses on strengthening my core, telling me we need to focus on making me into 'a tall giraffe'!", "What's wrong with extreme dieting and hard-core fitness plans is that they don't take into account the rest of your life.", "Yoga disciplines both the mind and the souls and not just your body. It helps me in having a constant positive outlook in life. I would love my family to adopt this form of fitness as well.", "Staying more controlled mentally stemmed from taking my fitness more seriously. When you're doing track work, sprints and so on, it's pretty painful, but that does make you feel better prepared and therefore mentally stronger when you're going into a match. You know, without a doubt, that you are strong enough to last.", "As a father, my first priority is to help my sons set and attain personal goals so they will develop self-confidence and individual strength. Engaging in regular fitness activities with my children helps me fulfill those responsibilities.", "Personally, I need a high level of physical fitness in order to feel at ease.", "I started running around my 30th birthday. I wanted to lose weight; I didn't anticipate the serenity. Being in motion, suddenly my body was busy and so my head could work out some issues I had swept under a carpet of wine and cheese. Good therapy, that's a good run.", "The spirit of the Olympic movement is great for young people because it teaches them about the training and discipline required to compete. Even if they don't make the teams, they can rededicate their lives to the art of sport, discipline, and physical fitness.", "I would rather exercise than read a newspaper.", "15 minutes a day! Give me just this and I'll prove I can make you a new man.", "My experience as a school nurse taught me that we need to make a concerted effort, all of us, to increase physical fitness activity among our children and to encourage all Americans to adopt a healthier diet that includes fruits and vegetables, but there is more.", "I would like to thank everyone who supported me to be fit for the Euros. I had some fitness problems before the tournament, but I am here now!", "Sexy is attitude, but fitness for me is my dance. I dance two hours nearly every day. You break into good sweat, and it doesn't even feel like exercise. Apart from that, I enjoy Pilates.", "Never, ever exercise in front of a TV or while reading. You lose 50 percent of the benefit of the exercise by not hearing and feeling your heart rate, your sweat and the pain levels that need to be encountered in fitness training.", "I do yoga, I do Bikram and I run, and I eat really healthy.", "What's important is to get into shape and then not to have to worry about it. I don't want to get on stage and not being able to do something. Not being physically fit doesn't work for me.", "It's not like I was trying to be sexy but I had to get fit because I had to be able to do stunts. Also I wanted that, if Bond took his clothes off, he looked like a man who did what he did, which was kill people for a living. I thought the only way to do that was to work out and get fit and buff and get physically into shape.", "Fitness has always been one of the top priorities in my life because that's the way I grew up, with soccer being the sport of choice.", "I tell my sons all the time, 'The most important thing in your life is fitness,' but a lot of fighters go overboard.", "When I was a little kid growing up in Iceland, I always dreamed about creating something that could have an impact on the whole world, and even as a young boy I was passionate about fitness and sports.", "I can work hard and be disciplined like a soldier, but I could never reach their level of fitness.", "The most important quality in a leader is that of being acknowledged as such. All leaders whose fitness is questioned are clearly lacking in force.", "Even though I'm not a competitive athlete, I have to still maintain things and try to keep myself fit because I am at that age where I need to make sure to get those regular checkups and make sure everything is in tact.", "Teaching kids about health and fitness is important to me. It's about being fit for life.", "I'm French, so I'm quite lazy about exercising, and I smoke. But I do love going for a run in the morning with my dog. That's all.", "Find fitness with fun dancing. It is fun and makes you forget about the dreaded exercise.", "I would say 90 percent of the stuff we do is technical anyway. If you look at a two-hour training day, 12 minutes are probably spent running or gaining fitness.", "In my view, fitness training isn't that important in England, as they all train with such intensity anyway and have a competitive edge when just sprinting. The matches are all hard-fought, too.", "My church has a health and fitness ministry to encourage our members to take care of spiritually and physically; how could I not?", "With fitness, I do Bikrams hot yoga. The gym that I have in my building is amazing. I love to do cardio and weights there.", "I don't lift weights. I do fitness exercises to stay strong.", "My priority is to turn people - especially kids - on to sports and being active so they don't even have to think about it being good for their health. If people participate for the fun of it, and believe me - it is fun, then fitness programs will be much more successful.", "For me, triathlons were something that was down to me and my fitness. Now, I really enjoy the pain in the triathlon of chasing someone down. It's a bit like chasing down Nico Rosberg in the last few laps at Silverstone - it makes you feel alive.", "Mental fitness is served by consciously redirecting our attention away from the constant bombardment from the media whose reason to be seems to be focused on keeping us in a state of constant alert.", "To keep my back from getting stiff, I have a strict regime every morning of stretching and do yoga once a week and Pilates. 'Strictly Come Dancing' in 2008 was great for my fitness.", "It is really important that we get more women doing exercise and being active, and those that have taken up boxing or boxing training will definitely find that it has a really positive impact on their health, fitness and well-being.", "I think it'd be wonderful if we could train young girls to be active in lots of ways and that they then wouldn't have to age at the same rate that they would if they were not more active. In other words, more physical fitness and not just the sporty kind, but the yoga, which is really important.", "I grew up watching Salman Khan and Arnold Schwarzenegger, who have always juggled fitness with acting. In real life, I'm a fitness freak. Besides, it is nice to look at an actor who is fit, and if you become a role model, that's a perk.", "Fitness is defined differently by everyone, but for me, the most important thing is being healthy. As tennis players, what we do is not the healthiest thing. We almost abuse our bodies.", "Obviously, when you're doing fitness work at a club all week and every week, it's all about specific drills for what you need to do on the pitch. So I'd be doing a different drill to the centre-midfielders. It's all specifically tailored for me. For example, my drills are high speed. It's all about trying to break the line with a sharp sprint.", "I'd love to look like my mum when I am her age. She taught ballet for years, and my attitude to exercise and fitness has definitely been influenced by her. She's 84 now, and I've watched how well she has aged, and a lot of that is to do with her fantastic posture.", "Sometimes fitness is a good thing to have, but you have to recognise that fitness takes you only so far, and skills are the most important thing. Fitness just helps you execute those cricketing skills for longer and more consistently, maybe.", "Overall, I think I'm in pretty good shape, but I'm not really someone that is gung-ho or a fitness fanatic.", "When 'Men's Health' reached out and said, 'Will you be on the 'Today Show' and do a fitness challenge?' I said, 'OK. I'm not showing them anything they don't already know.' But I'm going to take what some would argue is a negative or not substantive and turn it into a substantive thing to hopefully do some good for people.", "I'm freakishly competitive, so I set a date to achieve a certain weight or fitness.", "What you want is to rev up your metabolism so that you are burning fat and calories, not preserving fat and calories.", "I love to swim for miles; I could just go back and forth.", "I am about to get involved with the biggest cancer hospital in Norway. They are building a fitness center to work with patients. I will be a consultant.", "Mr. Gonzales' failure to respond to questions legitimately posed to him by the Senate raises grave doubts in my mind as to his fitness to serve the people of the United States as their Attorney General.", "I concentrate on exercises from the waist down, since that is the laziest part of a woman's body.", "I love Nautilus and stretching. The results are immediate, and that gives me the motivation to continue.", "A vigorous five-mile walk will do more good for an unhappy but otherwise healthy adult than all the medicine and psychology in the world.", "I swim like a fish and I have an amazing kick.", "In the British Special Air Service, combat fitness is all about running.", "When you have a certain fitness projection, it's going to give you an advantage. Having strength, stamina and speed is important because I'm working with dogs who can kill me.", "I'm not a waif-y girl and never will be. I think it's healthy when fitness experts encourage fitness rather than getting a certain body shape.", "There is a moment when you get older when your metabolism slows down and you don't feel like working out any more, so you don't want to keep yourself fit any more, but that's your decision. Why should you be judged for it?", "I haven't always been into fitness. But I noticed that when I'd be on stage playing a show, I could hardly make it through the fifth song without having to take a breather.", "Obviously, I come from one background, and the people that design fitness equipment have been doing it for years and years, and they know what works and doesn't work.", "Being a dancer is my metaphor for life because you have to know your body. Being a dancer and paying attention to fitness is all about moving in balance.", "Too much redesign has to do more with fad and fashion than with fitness and function. It is change for the sake of change. Such redesign is not only unnecessary, it is all too often also retrogressive, leading to things that work less effectively than those they were designed to replace.", "The public character of every public servant is legitimate subject of discussion, and his fitness or unfitness for office may be fairly canvassed by any person.", "When I was back to 100 per cent fitness, I was able to show what I was capable of. I like to think I will bring a freshness into the Euros, and now that I am captain, I am going to do my best to take responsibility.", "I'm doing four hours of gymnastics training a day, six days a week and then an extra two to three hours in a fitness center as well.", "My assumption was that people are already motivated to go to a fitness class. That's who I am. I was already ready to go out there and get to class. All I needed was a search tool. But it turns out people need more than that, and that's why gym memberships exist.", "Some people have that school of thought where fitness isn't enjoyable, but we're making it enjoyable, I think, by making it more fun, challenging, and engaging rather than this boring thing that you have to do. It's about using technology and data to change this experience.", "I have been through various fitness regimes. I used to run about five miles a day and I did aerobics for a while.", "If my Instagram or Twitter has gotten people to try healthy supplements or enjoy a new form of fitness and feel better about themselves, then that's pretty rad.", "We've all tried to bunk our gym session or dance class. A single routine can get monotonous. That's why I have decided to make my fitness regime fun by incorporating different workouts into my schedule. From dancing to yoga, I plan to keep it as interesting as possible so I'm never bored of working out.", "One of the things I've always enjoyed is moving around and staying fit. Physicality is such a big part of being an actor, but it's also about stillness and silence.", "I'm not a fitness model; I'm just a singer. If people focus on that, that's what I care about.", "I try to keep at a non-obsessive level of fitness. It's not about looking great, it's about just feeling good. So I do a lot of yoga. Bikram just blows my mind. It's mental as well as physical; if I don't train, I get very depressed.", "While I try to keep my fitness regimen consistent, during awards season, I'm especially conscious of what I'll be wearing and plan my workouts accordingly.", "Everything in moderation. I keep a healthy body, a healthy look. It's important not to be obsessive about anything - fitness, training, eating - because then you end up focusing on only that. And you can't obsess about anything when you're on the road.", "As the proud father of two teens and past Chairman to the Presidents Council on Physical Fitness and Sports, I am committed to educating parents and especially young people on ways to live a long, healthy and active life.", "When I was 10, I asked my parents for a set of weights. I had my Charles Atlas book to go along with that. Every time we went to the grocery store, I'd rush to the magazine area and read the ones with Arnold Schwarzenegger and all those guys on the covers: 'Pumping Iron,' 'Muscle and Fitness,' 'Muscle Builder by Joe Weider.'", "I understand only three things - films, fitness, and food.", "Just as you can't blindly follow fashion, you can't follow fitness, either.", "I decided to write 'True Refuge' during a major dive in my own health. Diagnosed with a genetic disease that affected my mobility, I faced tremendous fear and grief about losing the fitness and physical freedom I loved.", "Like most people I can be lazy, so it's nice to have a goal or deadline or reason to work out. I feel better when I get to exercise, or when I'm outdoors. I like to hike, swim and run, and I love to play soccer.", "I never stop working when I'm on stage, and that's my fitness.", "For a while after college, I was thinking of becoming a fitness trainer, and I am a certified aqua trainer.", "I try and maintain a little bit of fitness, man.", "I go to the gym every day. That tends to taper off when I'm at a tournament. During tournaments, I'm not trying to build fitness. I'm simply trying to keep away any kind of tension. I go for long walks to clear my head.", "As Mick Jagger will tell you, performing is an aerobic work-out. I've got the bass guitar, which is the heaviest of all the instruments, and I'm a little girl, in boiling-hot leather under the lights. You have to keep the fitness level up if you want to look good up there.", "I say, 'Use it or lose it.' I have my own fitness regime, which is centred around stretching, free-weights and fast walking. I also have a trainer half of the year, as I spend my summers in the south of France where I swim a lot.", "Virat Kohli has so far shown that he has more ability and talent than anybody else, and if he can play till 32 or 34 with same fitness and without injuries, he will come to a point where not even Vivian Richards neither Sachin Tendulkar had such a record.", "My morning starts with some form of exercise, and I give two hours - from 5:30 to 7:30 A.M. - to my personal fitness.", "The manager and the fitness staff condition every training session. They plan it out week by week on what players need. If players need a rest, they will do that; if players need to work hard, they will do that as well.", "I eat super healthy and I'm super fit. I dabble in every type of fitness. I have a trainer and I go to the gym. I do yoga as well.", "I've been into exercise my whole life, been a runner and been into health and fitness always.", "At my first Olympics, I didn't have a contract, and I wasn't making any money. After my first Olympics, I was working at 24 Hour Fitness at the front desk. I would go to practice in the morning, run home, shower, grab some food and then go straight to work. I didn't get off of work until 10 or 11 o'clock at night.", "I think when you come to Australia you immediately get the sense of fitness and taking care of yourself and being healthy, and it really shows.", "I know some people who are like, 'I love fitness,' and I feel like if you have to say that, you're still in the romance stage. I'm in the stage where I've been married to it for 60 years, and I don't think I'll ever get a divorce.", "I created a fitness club with five friends. We have weekly check-ins and a reward system - and group penalties if one of us slacks off.", "We talk a lot on 'Biggest Loser' about how fitness is a natural antidepressant, how it burns off stress. What I like about running is that it gives me time alone. I'm always busy, with people at work, with my kids. I love getting out for a run by myself and just listening to my music.", "For fitness, I've just bought a watch which keeps a track of how many calories I burn, what's my heart rate, which is very fascinating.", "With both kids, I started working out again at 16 days postpartum, but I treated myself with kindness, doing mild workouts, because my fitness level was lower.", "People assume that you need to run fast to get to optimum fitness, but the truth is endurance lifting makes you stronger and leaner.", "To hear both critics and defenders talk about the fitness of Judge Sonia Sotomayor for the Supreme Court, you'd think the most successful Supreme Court justices had been warm, collegial consensus-builders. But history tells a different story.", "At the start of his second term, one wonders less about Obama's fitness than his willingness: Why doesn't he do more to build and maintain the relationships required to govern in era of polarization?", "Kids are starting at such a low base rate in terms of fitness that it's taking them years to catch up to where people like me started from. Every little bit is making it more difficult for kids to succeed on a world stage.", "I've still got a small fitness and conditioning business where I travel round the world doing stuff for individuals and corporations, mainly fitness training.", "You need to eat normally and healthfully, and you need to exercise. I'm so passionate about this because I think people spend their lives not happy in their bodies.", "Obviously, your family life is the priority, but there's still other stuff you have to get done in a day. I think the way I make it work is by taking care of myself, and that includes fitness and eating right and all those things, but also by being very organized and punctual.", "I took up boxing as a fitness thing. I got obsessed, and I would go every day when I wasn't working. It's just an insane sport when you get into it.", "For most athletes, there's a focus on your own fitness, but I have to rely on my horse, too. I've been very lucky so far, and it hasn't presented a problem, but you can never count on a competition going as planned until you're there and actually doing it.", "Fitness of a top-class squash player is very important, and talent only can't do the job. They have to get training regularly for at least eight hours a day so that they could put some good show in a two-hour match.", "For much of the year, you're just trying to maintain your fitness. It's not often you get a lot of time to really concentrate on improving it.", "My fitness trainer's English, my physio's English, some of my friends are English. I don't have a problem with English people at all.", "Imagine how many women could excel in science if not for the pernicious myth that science and math are a man's game. Likewise, fitness isn't defined by the Arnold Schwarzeneggers of the world.", "It's better to train for 4-5 hours a week than to do ten hours one week then nothing for two weeks. It helps your body adapt and also maintains your fitness.", "Because I take care of my body, it doesn't look like the body of a woman of my years.", "On my days off, I like to be outdoors - on my bike or walking the dog or swimming - so it's important anyone I date is also into fitness.", "A year ago I had a back injury and followed a good nutrition program to help speed up my recovery. I focused on exercise and staying healthy in order to get back out on the ice.", "The only weights I lift are my dogs.", "Early in my career, I got roles that demanded that I be fit to carry off the angry young man look. Of course, I'm a fitness freak, and that's something I picked up from my dad.", "I have run two Olympic 'A' standard times over the past 12 months and with the time I ran at the African Championships last week I know my speed and fitness are constantly improving so that I will peak in time for the Olympics.", "It's very important to have the right clothing to exercise in. If you throw on an old T-shirt or sweats, it's not inspiring for your workout.", "At times, you are mentally but not physically prepared; at times, you are physically but not mentally prepared. I would be lying if I said it doesn't affect your performance. But the sooner you get over it, the better. So you discipline yourself. That is why fitness counts.", "You gotta have a body.", "I'm very active when I'm not pregnant, but I think fitness should be a natural part of your life, not something you have to force yourself to do.", "I am concentrating on my fitness levels so that I don't look old.", "Faith can make no appeal to reason or the fitness of things; its appeal is to the Word of God, and whatever is therein revealed, faith accepts as true.", "I have a pretty active presence on social networking sites, and every day there are messages from so many young girls telling me that they are happy B-Town has curvy women like me. I feel you should be happy the way you are. Of course, fitness is important, but not to the extent of obsession!", "I can't eat whatever I want, definitely not. I'm always controlled because I do a lot of fitness and triathlons, not just Formula One, so I always make sure I eat the right things.", "When I started out as a model, I took things for granted. Because I bagged work thanks to my looks, I didn't give my body any importance. I was a couch potato who'd eat anything. Then, in 2005, a tabloid ran a story calling me fat. I thought, 'I'm famous. How can I be fat?' It was a slap. I decided to get fit.", "I like starting off the new year fresh. I'm excited to see how 2013 turns out. Maybe because I'm an actress and I am always on a diet and fitness program, but my New Year's resolution is to let myself be nice to myself about my body.", "I am 5 ft 6 in, and at my peak, my vital statistics were 37-22-35. I didn't even think about my weight - but now I work hard at keeping healthy. Fortunately, my husband Richie is as much of a fitness buff as I am.", "I think a basic level of fitness can help the body cope with all manner of incidents.", "I love to sing. I also had a band during my college days in Saudi Arabia called Thousand Decibels. If not an actor, I would have become a singer. I am very passionate about work. I am a fitness freak: I go to gym before doing my shoot. I also do yoga.", "Bathrooms are, on a square foot basis, the most expensive room in the house to renovate. If you want to test your heart's fitness, try shopping for simple bathroom faucets. Add in the cost of the required valves, mixers and trims, and you may need reviving when you see the tally!", "Let's face it: fitness is boring. But it's critical to be extremely dedicated to whatever you decide to take up to achieve a desired result. There's no way you are going to get there without dedication, which is the key for me.", "I personally love to run outdoor fitness trails. I love the meditative value I get when out alone, challenging myself to run faster and higher.", "I believe it's extremely important to include some other type of fitness activity in your training, so cross training will help you to avoid injury when you are dancing.", "It's not about weight, it's about fitness, and one component of being fit is to have relatively low body fat, because fat is not very efficient, whereas muscle is.", "My bottom is so big it's got its own gravitational field.", "Fitness has always been one of my strengths. I can do all the long-distance runs. When I was at school and we entered the competitions, I used to do the 100m, 200m, and the 1500m as well, so it's never just been a pace thing.", "I might do a fitness video. Actually, more of a fatness video.", "When I was first introduced to CrossFit, I found it to be the hardest workout that I'd ever done. It wiped the floor with me, and I fell in love with it immediately. The results that I have seen in my strength and physicality have been unparalleled to any other things I have ever done in my more than 20 years in the fitness business.", "I'm 33 now and I seem to have hit a fitness plane. Shifting the wobbly bits isn't as easy as it used to be.", "I'm enjoying myself this year and for once I'm not chasing my fitness.", "People may say I developed an iron will, but what really happened is that I made myself much fitter. I think an iron will is always supported by fitness.", "The bowlers I respected or feared or rated were not the ones who gave me lip or stared at me or abused me. More the ones who, at any stage of the game, when had they had the ball in hand, they were going to be at me, and they were going to have the skill and the fitness and the ability to be aggressive.", "Football shape is one thing, and then 'futbol' shape is a completely other thing. It's a whole other level of fitness that you have to work to maintain.", "Our regular fitness programme means that the race lasting longer than others should not be a problem, but something you have to prepare for in Singapore is ensuring you always keep well-hydrated, as the heat and humidity can easily dehydrate you.", "At least for soccer players, it comes down to a blend of two types of fitness - your base endurance, which comes from longer distance running, and your speed, which comes from sprint-based workouts.", "They both go together; you can't be in front of the camera hosting a fitness television show in front of 75 million households and not have trained 6 days per week year round - in a bikini no less.", "The fitness builds the foundation for me as an actor to have clarity. Fitness has always been the base of where I start off as a performer.", "When I left EastEnders, I could have earned an absolute fortune from sexy calendars, shoots for lads' mags, fitness videos and reality shows. But I always turned them down.", "I thought I did well for someone who has been out for 10 or 11 months. Then I was sub against Liverpool and tried to play for the guys and work on my fitness.", "The goodness of a thing created is the perfection of its fitness for the use which it serves. Now that use is either particular or universal.", "When I do get time, I like to hike and I take lots of vitamins and powders to keep healthy.", "Once you are over 30, 35 years old, I think everyone should get down to the gym and start moving again.", "The health industry, the fitness industry, was really starting to pick up. This was around the mid 80's.", "I have been particularly struck with the overwhelming evidence which is given as to the fitness of the natives of India for high offices and employments.", "I had something to prove and went in the studio and started writing. I got into fitness and style and learned the whole craft. That was when I wrote everything on the album. I put out 'Don't Ya,' and it took off.", "You can control what you put in your body - 100 percent. You really can control your level of fitness and how your body looks.", "Beside the brand-ambassador elements of the modern racing driver, the evolution of the athlete has mandated that as drivers, we are very committed to fitness.", "I don't want to lose my fitness. I'm 45. I have two babies. I've got a long way to go and I want to keep in tiptop shape. There's no magic bullet.", "I train Monday through Saturday. I usually have fitness training for 90 minutes, then I'm on the tennis court for 3 to 4 hours.", "I always knew I'd keep at it with the plodding doggedness that I used to master lump-less gravy and wriggle out of fitness classes; I always knew I'd get a zillion rejection slips. I figured I'd write part time while working various full-time office jobs, and maybe, maybe in my 50s, I'd be able to quit and try writing full time.", "Fitness is a curve. You can be Lance Armstrong, or you can be really out of shape at the opposite end. People enter the curve wherever they are and then they can move up the curve, by better nutrition and better exercise.", "Beauty connotes humanity. We call a natural object beautiful because we see that its form expresses fitness, the perfect fulfillment of function.", "Once in a while I'll get moved to do some exercise. It's something I long for but the biggest problem is bending down and putting my tennis shoes on. Once I go out I'm OK.", "We've got to get people out of their cars, out of those drive-thru windows, get them walking, get them in parks and get them more active.", "For guys who are into fitness, I think it's important to wear slim-fit stuff that is pretty tight so they can show off the bodies they have been working hard to have. Women are going to appreciate that.", "I'm really into fitness, so my hobbies are yoga, Pilates, and working out.", "Dance never really goes away; it just reforms and reinvents, and it's become more athletic with new connection to fitness and sport. Dance used to have this exclusivity, but not any more.", "I just have to express myself somehow, either through singing, dance or fitness. You get sick of it; you have days where you think you don't want to do it, but generally after I've done something, I feel better. That's why I do the exercise: to earn my bar of chocolate and cappuccino.", "I have found a flat on Merseyside and am settling down here. If I can keep playing and get back to full match fitness, I know I have a lot to offer still.", "Every morning, I eat one fat-free yogurt with a sliced peach when peaches are in season, and one thin slice of whole-wheat bread. The same thing. I don't want to get fat. And I want to keep my fitness.", "I became a fitness fiend when I was about 17 or 18.", "I keep up with everything in terms of health, fitness, nutrition, skin care, hair, nails. Really, everything. I'm an avid reader of every women's health newsletter from every hospital in the country.", "For a good workout, I go to At One Fitness in North Hollywood, where my trainer, Jon Allsop, puts me through it all. I like it because it's a small gym and I've known the people for a long time. Jon will have me do cross-training where I'll lift weights, jump rope, throw around a medicine ball and I never get to stop.", "I've had one very bad ankle injury but otherwise I've been incredibly lucky with my fitness. I've worked hard at it and I've always been fit even compared to other players. That sustains you through various parts of your career, but I am 36.", "I'm healthy now. I probably wouldn't say I'm at my best fitness level and I haven't played that much lately, but I'm healthy and that's all that matters.", "Now I say that if you run more than 15 miles a week, it's for something other than aerobic fitness. Once you pass 15 miles, you do not see much further improvement.", "I've published one book before, and now I'm writing a book of essays and stories about life in Tokyo. And I have one book coming out in May in Germany, about fitness.", "I'm still very professional about my fitness. I stay in trim as I always did.", "There are similarities between business and sport, in the pressures involved and in the fitness aspect too.", "Yoga's an amazing release.", "I enjoy going to the Y. I take all the fitness classes that my dad takes; that's sort of our bonding - anything athletic, anything sports related.", "Fitness will be a major factor in the first race and I think that will play into the hands of drivers who have been racing recently, rather than people like me who haven't raced properly for a decade. I'am not one of the favourites to start with.", "I'm an athlete, so I can get up one day and run and it wouldn't bother me. I don't get the time because I work for long hours every day. Being constantly on the move itself helps me stay fit. I don't go to a gym. I use the stairs, not the lift. I'm not into fitness, but I feel I should start, as it's healthy.", "I was a bit worried coming back to the Premiership from America, but I have been pleased with my form, and the interest I have received has been good for my ego. I have no worries about my fitness, and I am really looking forward to the season starting now.", "I have always maintained a high level of fitness, and that is why I am still able to handle the demands of playing in the Premiership. People have always commented on my fitness, and it's something I pride myself on.", "I think that our culture is doing something to women - let's say women in their late 30s and 40s and probably even 50s, - where they really are expected to keep this insane level of fitness and youth. I find that just a real waste of women's lives. I really do think that.", "With fitness, I decided that I wanted to get into shape, and my passion for fitness and a desire to help other people do the same made me decide to do a fitness video. People always tell me they want to work out to my songs, so why not make a fitness DVD.", "My mom was a professional fitness competitor, so I go into the gym with her. I train with my dad and mother. It's embarrassing, because she's really strong.", "My fitness is good. I hope to improve it even further during training.", "The main thing is that it's nice to see these young people - 9 to 14 years old - take the opportunity to get more involved in their health and fitness. We need more kids to be more active.", "Shearer could be at 100 per cent fitness, but not peak fitness.", "I also meet with city officials, representatives from governors' offices, really anyone in that sort of position who has shown an interest in youth fitness, to let them know why this sort of program is so important. I give the same message when I speak at conferences.", "When I'm on the road, I'll break my exercise into a cardio session and a weights session.", "I do a lot of biking. I need that mileage and the long-distance stuff because tennis demands it. My fitness trainer is always trying to convince me to do an Ironman. I can probably run the marathon, I can make the 112 miles on the bike, but I will never swim for 2.4 miles. I will die after 100 meters.", "Don't get me wrong, I think bikes are terrific. I own several of my own, including a trendy mountain style, and ride them for pleasure and light exercise.", "My husband and I own a CrossFit Gym. Crossfit is perfect for me because it's always competitive, all the workouts are in a class environment, and it's different every day. It's a constantly varied functional fitness workout done with intensity.", "I don't do very well with extremes of any kind - extreme diets, extreme fitness - so moderation makes a lot of sense, and Hershey's has really great portion-friendly desserts to help people incorporate treats into their lifestyles so they don't feel like they're depriving themselves and are still living a balanced life.", "I'm such a fitness freak that I eat so plain, it's gross. I have oatmeal in the morning and then I have chicken breasts and vegetables and spinach shakes.", "It is such a great opportunity to be the face of a brand which I remember wearing as a little kid and running around in half-naked. Bonds is now getting very serious about fitness, and their range is amazing. It's beautiful and comfy.", "One of my assets is my fitness. My fitness around the net and my movement: that's my defense to the power.", "I remember Simon O'Donnell being struck with cancer during Australia's 1987 World Cup campaign. I know very well what it is like to have a teammate who has been struck with a potentially fatal disease. He fought through: managed to get himself back to 100% fitness and back to playing again.","Health is the greatest gift, contentment the greatest wealth, faithfulness the best relationship.", "Treasure the love you receive above all. It will survive long after your good health has vanished.", "To enjoy good health, to bring true happiness to one's family, to bring peace to all, one must first discipline and control one's own mind. If a man can control his mind he can find the way to Enlightenment, and all wisdom and virtue will naturally come to him.", "Calm mind brings inner strength and self-confidence, so that's very important for good health.", "I believe that the greatest gift you can give your family and the world is a healthy you.", "To enjoy the glow of good health, you must exercise.", "Saving our planet, lifting people out of poverty, advancing economic growth... these are one and the same fight. We must connect the dots between climate change, water scarcity, energy shortages, global health, food security and women's empowerment. Solutions to one problem must be solutions for all.", "It is health that is real wealth and not pieces of gold and silver.", "To keep the body in good health is a duty... otherwise we shall not be able to keep our mind strong and clear.", "I have been very blessed in my life and rewarded with good friends and good health. I am grateful and happy to be able to share this.", "Early to bed and early to rise makes a man healthy, wealthy and wise.", "If you don't think your anxiety, depression, sadness and stress impact your physical health, think again. All of these emotions trigger chemical reactions in your body, which can lead to inflammation and a weakened immune system. Learn how to cope, sweet friend. There will always be dark days.", "All mankind... being all equal and independent, no one ought to harm another in his life, health, liberty or possessions.", "Good health and good sense are two of life's greatest blessings.", "Sleep is that golden chain that ties health and our bodies together.", "Time and health are two precious assets that we don't recognize and appreciate until they have been depleted.", "The equal right of all citizens to health, education, work, food, security, culture, science, and wellbeing - that is, the same rights we proclaimed when we began our struggle, in addition to those which emerge from our dreams of justice and equality for all inhabitants of our world - is what I wish for all.", "A healthy attitude is contagious but don't wait to catch it from others. Be a carrier.", "We are all born with a unique genetic blueprint, which lays out the basic characteristics of our personality as well as our physical health and appearance... And yet, we all know that life experiences do change us.", "Without health life is not life; it is only a state of langour and suffering - an image of death.", "Everybody needs beauty as well as bread, places to play in and pray in, where nature may heal and give strength to body and soul.", "Healing is a matter of time, but it is sometimes also a matter of opportunity.", "Health is not valued till sickness comes.", "Our greatest happiness does not depend on the condition of life in which chance has placed us, but is always the result of a good conscience, good health, occupation, and freedom in all just pursuits.", "Good health is not something we can buy. However, it can be an extremely valuable savings account.", "There is no health without mental health; mental health is too important to be left to the professionals alone, and mental health is everyone's business.", "Look up, laugh loud, talk big, keep the color in your cheek and the fire in your eye, adorn your person, maintain your health, your beauty and your animal spirits.", "True friendship is like sound health; the value of it is seldom known until it is lost.", "Happiness is nothing more than good health and a bad memory.", "The only way to keep your health is to eat what you don't want, drink what you don't like, and do what you'd rather not.", "My body is like breakfast, lunch, and dinner. I don't think about it, I just have it.", "The first wealth is health.", "Water is life, and clean water means health.", "It is unfortunately true that our generation and that of your parents have left you with a big mess that will now be yours to clean up: wars, budget challenges, pollution, global warming, battles of health care, natural disasters. They're all there for you. We're willing those to you. Are you ready?", "If you're happy, if you're feeling good, then nothing else matters.", "I know a man who gave up smoking, drinking, sex, and rich food. He was healthy right up to the day he killed himself.", "It's so important to realize that every time you get upset, it drains your emotional energy. Losing your cool makes you tired. Getting angry a lot messes with your health.", "People talk about physical fitness, but mental health is equally important. I see people suffering, and their families feel a sense of shame about it, which doesn't help. One needs support and understanding. I am now working on an initiative to create awareness about anxiety and depression and help people.", "It is no measure of health to be well adjusted to a profoundly sick society.", "In my opinion, the battles over birth control and Planned Parenthood are primarily neither political nor religious. This is an issue of equality for women. This is an issue of women's rights: Planned Parenthood is the most important private provider of reproductive health care for women in the United States.", "It takes more than just a good looking body. You've got to have the heart and soul to go with it.", "Health is the greatest possession. Contentment is the greatest treasure. Confidence is the greatest friend. Non-being is the greatest joy.", "The typical response from people when I tell them I'm diabetic is, 'Oh, I'm sorry to hear that.' You know, I'm not. I'm a better athlete because of diabetes rather than despite it. I'm more aware of my training, my fitness and more aware of nutrition. I'm more proactive about my health.", "A healthy outside starts from the inside.", "Health is the thing that makes you feel that now is the best time of the year.", "There's nothing more important than our good health - that's our principal capital asset.", "We need to change the culture of this topic and make it OK to speak about mental health and suicide.", "Learning is the beginning of wealth. Learning is the beginning of health. Learning is the beginning of spirituality. Searching and learning is where the miracle process all begins.", "The power of community to create health is far greater than any physician, clinic or hospital.", "I've always believed fitness is an entry point to help you build that happier, healthier life. When your health is strong, you're capable of taking risks. You'll feel more confident to ask for the promotion. You'll have more energy to be a better mom. You'll feel more deserving of love.", "Be careful about reading health books. You may die of a misprint.", "True security is based on people's welfare - on a thriving economy, on strong public health and education programmes, and on fundamental respect for our common humanity. Development, peace, disarmament, reconciliation and justice are not separate from security; they help to underpin it.", "Your competition is not other people but the time you kill, the ill will you create, the knowledge you neglect to learn, the connections you fail to build, the health you sacrifice along the path, your inability to generate ideas, the people around you who don't support and love your efforts, and whatever god you curse for your bad luck.", "Being in control of your life and having realistic expectations about your day-to-day challenges are the keys to stress management, which is perhaps the most important ingredient to living a happy, healthy and rewarding life.", "When wealth is lost, nothing is lost; when health is lost, something is lost; when character is lost, all is lost.", "The medical literature tells us that the most effective ways to reduce the risk of heart disease, cancer, stroke, diabetes, Alzheimer's, and many more problems are through healthy diet and exercise. Our bodies have evolved to move, yet we now use the energy in oil instead of muscles to do our work.", "Natural forces within us are the true healers of disease.", "Leave all the afternoon for exercise and recreation, which are as necessary as reading. I will rather say more necessary because health is worth more than learning.", "Hearty laughter is a good way to jog internally without having to go outdoors.", "Rest when you're weary. Refresh and renew yourself, your body, your mind, your spirit. Then get back to work.", "The body needs its rest, and sleep is extremely important in any health regimen. There should be three main things: eating, exercise and sleep. All three together in the right balance make for a truly healthy lifestyle.", "At Thanksgiving, I always start at the top of my list and say I'm grateful for friends, family, and good health. Then I get more superficial... like being thankful for my Louboutins.", "Money doesn't mean anything to me. I've made a lot of money, but I want to enjoy life and not stress myself building my bank account. I give lots away and live simply, mostly out of a suitcase in hotels. We all know that good health is much more important.", "My trust in God flows out of the experience of his loving me, day in and day out, whether the day is stormy or fair, whether I'm sick or in good health, whether I'm in a state of grace or disgrace. He comes to me where I live and loves me as I am.", "It was the labor movement that helped secure so much of what we take for granted today. The 40-hour work week, the minimum wage, family leave, health insurance, Social Security, Medicare, retirement plans. The cornerstones of the middle-class security all bear the union label.", "You cannot have maternal health without reproductive health. And reproductive health includes contraception and family planning and access to legal, safe abortion.", "My personal goals are to be happy, healthy and to be surrounded by loved ones.", "Countries with higher levels of gender equality have higher economic growth. Companies with more women on their boards have higher returns. Peace agreements that include women are more successful. Parliaments with more women take up a wider range of issues - including health, education, anti-discrimination, and child support.", "You know, all that really matters is that the people you love are happy and healthy. Everything else is just sprinkles on the sundae.", "There isn't anybody out there who doesn't have a mental health issue, whether it's depression, anxiety, or how to cope with relationships. Having OCD is not an embarrassment anymore - for me. Just know that there is help and your life could be better if you go out and seek the help.", "I want to thank God, obviously for the health, for the talent He's given me, for my family who supports me, for the things that basketball's taught me on and off the court. For the people that I've been able to meet through the game of basketball.", "The science of psychology has been far more successful on the negative than on the positive side... It has revealed to us much about man's shortcomings, his illnesses, his sins, but little about his potentialities, his virtues, his achievable aspirations, or his psychological health.", "Depression has been called the world's number one public health problem. In fact, depression is so widespread it is considered the common cold of psychiatric disturbances. But there is a grim difference between depression and a cold. Depression can kill you.", "Without your health, you've got nothing going on. I thank God every day for good health.", "It's better to be healthy alone than sick with someone else.", "The healthy man does not torture others - generally it is the tortured who turn into torturers.", "AIDS is a plague - numerically, statistically and by any definition known to modern public health - though no one in authority has the guts to call it one.", "Advances in technology will continue to reach far into every sector of our economy. Future job and economic growth in industry, defense, transportation, agriculture, health care, and life sciences is directly related to scientific advancement.", "Self-esteem is as important to our well-being as legs are to a table. It is essential for physical and mental health and for happiness.", "Women in particular need to keep an eye on their physical and mental health, because if we're scurrying to and from appointments and errands, we don't have a lot of time to take care of ourselves. We need to do a better job of putting ourselves higher on our own 'to do' list.", "Apart from education, you need good health, and for that, you need to play sports.", "If you look at suicides, most of them are connected to depression. And the mental health system just fails them. It's so sad. We know what to do. We just don't do it.", "The foundation of success in life is good health: that is the substratum fortune; it is also the basis of happiness. A person cannot accumulate a fortune very well when he is sick.", "The health effects of air pollution imperil human lives. This fact is well-documented.", "If we could give every individual the right amount of nourishment and exercise, not too little and not too much, we would have found the safest way to health.", "I always had a philosophy which I got from my father. He used to say, 'Listen. God gave to you the gift to play football. This is your gift from God. If you take care of your health, if you are in good shape all the time, with your gift from God no one will stop you, but you must be prepared.'", "Vaccines and antibiotics have made many infectious diseases a thing of the past; we've come to expect that public health and modern science can conquer all microbes. But nature is a formidable adversary.", "Everyone has their own definition of a healthy lifestyle, and mine has come to mean making health a priority but not an obsession.", "Beauty is a gift, just like good health or intelligence. The only thing is not to be proud of being beautiful. Because you didn't do anything - it was given to you.", "It has always been the role of government to help solve problems, including and especially health crises. Obesity is a health epidemic across our country, and we have a responsibility as a government and a society to do all we can to promote good nutrition and healthy eating so we can reverse this alarming trend.", "Youth is the spirit of adventure and awakening. It is a time of physical emerging when the body attains the vigor and good health that may ignore the caution of temperance. Youth is a period of timelessness when the horizons of age seem too distant to be noticed.", "Vaccines are the tugboats of preventive health.", "Health is correlated with quality of life. If you get regular physical activity, have social connections, control your cholesterol, keep your blood pressure at a normal level, don't smoke - these things can make an enormous difference not only in how long you live, but how much you enjoy your life in those years.", "We have to treat smoking as a major public health issue. We have to reduce the extent to which young people start smoking, and one of the issues is the extent to which display of cigarettes and brands does draw young people into smoking in the first place.", "Every second, every day, every year, we fail to address demand for reproductive health and family planning services. Lives are lost, and girls' opportunities to thrive and contribute to their country's development shrink. These are real people.", "The way we work in public health is, we make the best recommendations and decisions based on the best available data.", "He who has health, has hope; and he who has hope, has everything.", "You're in pretty good shape for the shape you are in.", "Besides taking jobs from American workers, illegal immigration creates huge economic burdens on our health care system, our education system, our criminal justice system, our environment, our infrastructure and our public safety.", "Vaccines are the most cost-effective health care interventions there are. A dollar spent on a childhood vaccination not only helps save a life, but greatly reduces spending on future healthcare.", "I take a massage each week. This isn't an indulgence, it's an investment in your full creative expression/productivity/passion and sustained good health.", "Health is the vital principle of bliss, and exercise, of health.", "Soil is a living ecosystem, and is a farmer's most precious asset. A farmer's productive capacity is directly related to the health of his or her soil.", "I support health care for people. I want people well taken care of. But I also want health care that we can afford as a country. I have people and friends closing down their businesses because of Obamacare.", "Religion is part of the human make-up. It's also part of our cultural and intellectual history. Religion was our first attempt at literature, the texts, our first attempt at cosmology, making sense of where we are in the universe, our first attempt at health care, believing in faith healing, our first attempt at philosophy.", "Public health service should be as fully organized and as universally incorporated into our governmental system as is public education. The returns are a thousand fold in economic benefits, and infinitely more in reduction of suffering and promotion of human happiness.", "Hunger and malnutrition have devastating consequences for children and have been linked to low birth weight and birth defects, obesity, mental and physical health problems, and poorer educational outcomes.", "Universal coverage, not medical technology, is the foundation of any caring health care system.", "Illegal immigration costs taxpayers $45 billion a year in health care, education, and incarceration expenses.", "The health of the people is of supreme importance. All measures looking to their protection against the spread of contagious diseases and to the increase of our sanitary knowledge for such purposes deserve attention of Congress.", "Knowing your HIV status is so important for your future health and that of your loved ones.", "It is wisest to be impartial. If you have health, but are attached to it, you will always be afraid of losing it. And if you fear that loss, but become ill, you will suffer. Why not remain forever joyful in the Self?", "It is essential that the women's preventive coverage benefit, including contraception, be available to all women, regardless of what health plan they have or where they work - as Congress intended. Providing access to birth control just makes good sense.", "Over 120 Aboriginal communities run their own health services - some have been doing so for 30 years. They struggle with difficult medical problems. They also try to deal with counselling, stolen generations issues, family relationships, violence, suicide prevention.", "All the money in the world can't buy you back good health.", "A library is a place that is a repository of information and gives every citizen equal access to it. That includes health information. And mental health information. It's a community space. It's a place of safety, a haven from the world.", "Make no mistake about it. Bad habits are called 'bad' for a reason. They kill our productivity and creativity. They slow us down. They hold us back from achieving our goals. And they're detrimental to our health.", "The groundwork of all happiness is health.", "True health infuses positive energy in the mind, body and spirit; it is a main focus in my life.", "Let no one be slow to seek wisdom when he is young nor weary in the search of it when he has grown old. For no age is too early or too late for the health of the soul.", "Happiness is good health and a bad memory.", "Our landscapes connect us to our history; they are the source of our character as a peopl, as well as our health, our safety, and our prosperity. Natural resources enrich us economically, yes. But they also enrich us aesthetically and recreationally and culturally and spiritually.", "A truly moral health care system should start out by covering all of its citizens with basic health care. It would not be seduced by its technology and fancy buildings.", "What is called genius is the abundance of life and health.", "To be stupid and selfish and to have good health are the three requirements for happiness. Though if stupidity is lacking, the others are useless.", "We take our kids for physical vaccinations, dental exams, eye checkups. When do we think to take our - our son or daughter for a mental health checkup?", "The torch relay is an excellent embodiment of all that the Olympic Games have come to symbolise - a celebration of the human spirit. Personally to me, it represents striving to be the best in whatever we do, never giving up despite the odds, and a commitment to health and fitness.", "In the midst of these hard times it is our good health and good sleep that are enjoyable.", "As an athlete, I understood the value of my health insurance. I knew that in my profession, injuries were common and could happen at any time.", "Climate change, demographics, water, food, energy, global health, women's empowerment - these issues are all intertwined. We cannot look at one strand in isolation. Instead, we must examine how these strands are woven together.", "The problem with the stigma around mental health is really about the stories that we tell ourselves as a society. What is normal? That's just a story that we tell ourselves.", "If our children are becoming teenagers who are abusive, have mental health issues, and are committing heinous crime, it only means that we have failed them as a society. We have failed to give them a safe, nurturing environment to ensure that they are well-balanced, useful persons in the society.", "As of 2013, according to the World Health Organization, 35 million people were estimated to be living with HIV or AIDS globally, and 39 million have died from the disease. The epidemic of denial won, and now everyone knows there is money in the making of drugs for AIDS.", "Today there are people trying to take away rights that our mothers, grandmothers and great-grandmothers fought for: our right to vote, our right to choose, affordable quality education, equal pay, access to health care. We the people can't let that happen.", "Lack of education, old age, bad health or discrimination - these are causes of poverty, and the way to attack it is to go to the root.", "A child's mental health is just as important as their physical health and deserves the same quality of support.", "Obesity affects every aspect of a people's lives, from health to relationships.", "By improving health, empowering women, population growth comes down.", "As long as man continues to be the ruthless destroyer of lower living beings he will never know health or peace. For as long as men massacre animals, they will kill each other.", "We farm workers are closest to food production. We were the first to recognize the serious health hazards of agriculture pesticides to both consumers and ourselves.", "The problem is that everywhere the gas drilling industry goes, a trail of water contamination, air pollution, health concerns and betrayal of basic American civic and community values follows.", "Laughter is important, not only because it makes us happy, it also has actual health benefits. And that's because laughter completely engages the body and releases the mind. It connects us to others, and that in itself has a healing effect.", "We need, ultimately, to be able to view mental health with the same clear-headedness we show when talking about physical health.", "I heard a definition once: Happiness is health and a short memory! I wish I'd invented it, because it is very true.", "We can start with housing, the sturdiest of footholds for economic mobility. A national affordable housing program would be an anti-poverty effort, human capital investment, community improvement plan, and public health initiative all rolled into one.", "Many kids come out of college, they have a credit card and a diploma. They don't know how to buy a house or a car or health insurance or life insurance. They do not know basic microeconomics.", "It is amazing that people who think we cannot afford to pay for doctors, hospitals, and medication somehow think that we can afford to pay for doctors, hospitals, medication and a government bureaucracy to administer it.", "The wellness and prevention market will outgrow the health care market.", "Therefore in medicine we ought to know the causes of sickness and health.", "True silence is the rest of the mind, and is to the spirit what sleep is to the body, nourishment and refreshment.", "Man needs difficulties; they are necessary for health.", "The communities and countries best at using energy to optimize a microclimate for human life are also the ones whose people have the longest average lifespans. Canada, Sweden, and Iceland - places with inhospitable winter weather - are frontrunners in sustaining human health and life.", "Love is not as important as good health. You cannot be in love if you're not healthy. You can't appreciate it.", "There are over 200 million illiterate women in India. This low literacy negatively impacts not just their lives but also their families' and the country's economic development. A girl's lack of education also has a negative impact on the health and well-being of her children.", "We can be thankful President Barack Obama is taking aim at one of the prime causes of climate change and extreme weather: air pollution. The EPA's carbon pollution standards are the most significant step forward our country has ever taken to protect our health by addressing climate change.", "One of the best aspects of health care reform is it starts to emphasize prevention.", "After one Olympics, if we invest in sports and say we will get a gold medal in the next Olympic, it doesn't work like that in sports. How it works is that you provide the infrastructure, provide education about nutrition and health.", "In this media-drenched, multitasking, always-on age, many of us have forgotten how to unplug and immerse ourselves completely in the moment. We have forgotten how to slow down. Not surprisingly, this fast-forward culture is taking a toll on everything from our diet and health to our work and the environment.", "It's the thing I struggle with every day: the mental diligence and stamina needed to sit in front of the computer, open the file, start writing and to keep doing so, word after word, until I've created the next story. A combination of learning disability and chronic health issues make that the hardest thing for me.", "I see taking care of my emotional and mental health in the same way that I see taking care of a garment: After it's been through wear and tear, it needs attention.", "We need a comprehensive strategy that includes expanding criminal background checks for all commercial gun sales, dedicated federal law to combat gun trafficking, and a strong commitment to mental health services.", "Water, air, and cleanness are the chief articles in my pharmacy.", "After a century of striving, after a year of debate, after a historic vote, health care reform is no longer an unmet promise. It is the law of the land.", "What can be added to the happiness of a man who is in health, out of debt, and has a clear conscience?", "Perfect freedom is as necessary to the health and vigor of commerce as it is to the health and vigor of citizenship.", "With age comes the understanding and appreciation of your most important asset, your health.", "Eventually, competition and adventure wane, and I enter my ibuprofen phase. Tweaky hamstrings and achy knees restrict mileage, but I continue running for health, sanity, and the ritual of a Sunday trail run with like-minded buddies. We discuss the nagging injuries that bedevil us, and remember the good old days when we were kings.", "Today it is time for every child to have a right to life, right to freedom, right to health, right to education, safety, the right to dignity, right to equality, and right to peace.", "The only secret to food combination is a balance of protein, carbs and fat - they all play a key role in our health.", "The devil has put a penalty on all things we enjoy in life. Either we suffer in health or we suffer in soul or we get fat.", "Mental health needs a great deal of attention. It's the final taboo and it needs to be faced and dealt with.", "Faith and prayer are the vitamins of the soul; man cannot live in health without them.", "Capital is reckless of the health or length of life of the laborer, unless under compulsion from society.", "You cannot achieve environmental security and human development without addressing the basic issues of health and nutrition.", "Many of the original New Deal programs required heavy manual labor. WPA workers built hundreds of schools, health clinics, roads, park facilities, and community centers. Much of what we now call our 'infrastructure' - highways, buildings, power plants, etc. - is here thanks to thousands of WPA workers.", "I have not been that wise. Health I have taken for granted. Love I have demanded, perhaps too much and too often. As for money, I have only realized its true worth when I didn't have it.", "I just have to be very clear. Whether or not I lose weight or stay the same, it's purely a choice of mine for health. Not because I think that plus size, curvy, voluptuous, big bodies aren't attractive - because I think they're awesome and sexy.", "People with mental health problems are almost never dangerous. In fact, they are more likely to be the victims than the perpetrators. At the same time, mental illness has been the common denominator in one act of mass violence after another.", "A desire to be in charge of our own lives, a need for control, is born in each of us. It is essential to our mental health, and our success, that we take control.", "The bottom line: health care reform is about the patient, not about the physician.", "I feel blessed that I haven't seen or felt real pain to be immune to it. But I am dreading the time it comes. I feel blessed to have everything going fine. My parents' health is good, my brothers are well-settled, I have a great brother-in-law and my own career is doing fine. I hope and pray that I am fit and fine always.", "I am just enjoying what cricket has given me. In sports, it's obviously really important for all of us to remain fit - and health is wealth, so health comes with the sport.", "When you're young, you don't think very far ahead. You just think in terms of the next day, the next week, the next competition. You don't think about injuries that could threaten your long-term health.", "You can't afford to get sick, and you can't depend on the present health care system to keep you well. It's up to you to protect and maintain your body's innate capacity for health and healing by making the right choices in how you live.", "Health messages are simply overwhelmed, in volume and in effectiveness, by junk-food ads that often deploy celebrities or cartoon characters to great effect. We may know that eating fruits and vegetables is good for us, but the preponderance of the signals we get - and especially the signals children get - push us in the direction of junk food.", "A person whose mind is quiet and satisfied in God is in the pathway to health.", "I drink coffee in the morning and a few cups throughout the day. Among coffee's health benefits are lower risk of Parkinson's, Type 2 diabetes, heart disease and dementia.", "Whenever we feel stressed out, that's a signal that our brain is pumping out stress hormones. If sustained over months and years, those hormones can ruin our health and make us a nervous wreck.", "The ultimate purpose of religious life is to make this evolution move in a direction far more important to the destiny of the ego than the moral health of the social fabric which forms his present environment.", "But if you're asking my opinion, I would argue that a social justice approach should be central to medicine and utilized to be central to public health. This could be very simple: the well should take care of the sick.", "The health care system is really designed to reward you for being unhealthy. If you are a healthy person and work hard to be healthy, there are no benefits.", "For the sake of our health, our children and grandchildren and even our economic well-being, we must make protecting the planet our top priority.", "Getting kids moving is a key factor in tackling obesity and health problems among the young.", "Lost wealth may be replaced by industry, lost knowledge by study, lost health by temperance or medicine, but lost time is gone forever.", "Make space in your life, space for health and happiness.", "Medicine sometimes snatches away health, sometimes gives it.", "A man is not rightly conditioned until he is a happy, healthy, and prosperous being; and happiness, health, and prosperity are the result of a harmonious adjustment of the inner with the outer of the man with his surroundings.", "For sleep, riches and health to be truly enjoyed, they must be interrupted.", "If the childhood obesity epidemic remains unchecked, it will condemn many of our kids to shorter lives, as well as the emotional and financial burdens of poor health.", "Decades of scientific research has proven that carbon pollution is harmful to human health and causes global warming.", "Look, if you have somebody who doesn't have health insurance, who doesn't have a doctor or dentist, and in order to deal with their cold or flu or dental problem, they go to an emergency room - in general, that visit will cost ten times more than walking into a community health center.", "America's health care system is neither healthy, caring, nor a system.", "You can't take good health for granted.", "The art of healing comes from nature, not from the physician. Therefore the physician must start from nature, with an open mind.", "All the evidence that we have indicates that it is reasonable to assume in practically every human being, and certainly in almost every newborn baby, that there is an active will toward health, an impulse towards growth, or towards the actualization.", "Having good health, being able to breathe and be happy, that's one of the most beautiful gifts. On top of that, I have the gift to play music and make people happy through that. I'm just telling you from my heart, I'm so in love with life.", "I'll tell you what I'm grateful for, and that's the clarity of understanding that the most important things in life are health, family and friends, and the time to spend on them.", "Tobacco is the only industry that produces products to make huge profits and at the same time damage the health and kill their consumers.", "Coal mining is an industry rife with mismanagement, corruption, greed and an almost blatant disregard for the safety, health and quality of life of its work force. Everyone knows this. Everyone has always known it.", "Cutting back on calories is not the answer to successful weight loss and successful health... you have to increase the quality of what you eat, not just reduce the quantity.", "Breast cancer alone kills some 458,000 people each year, according to the World Health Organization, mainly in low- and middle-income countries. It has got to be a priority to ensure that more women can access gene testing and lifesaving preventive treatment, whatever their means and background, wherever they live.", "I would prefer to live forever in perfect health, but if I must at some time leave this life, I would like to do so ensconced on a chaise longue, perfumed, wearing a velvet robe and pearl earrings, with a flute of champagne beside me and having just discovered the answer to the last problem in a British cryptic crossword.", "Mental health can improve overall well-being and prevent other illnesses. And since mental health problems have a serious economic impact on vulnerable communities, making them a priority can save lives and markedly improve people's quality of life.", "Illegal immigration is not just a matter of interest in states along our border with Mexico. It is having an effect on local economies, schools, health care delivery, and public safety all across the country.", "There's an opportunity for the pharmacist to play a much greater role in health care, especially with what we have going on in this country with the shortage of primary-care physicians.", "Community health centers do a great deal with limited resources. They provide critical medical care services to many who would otherwise have no other place to go or would end up in an emergency room.", "Not necessity, not desire - no, the love of power is the demon of men. Let them have everything - health, food, a place to live, entertainment - they are and remain unhappy and low-spirited: for the demon waits and waits and will be satisfied.", "Most Christian 'believers' tend to echo the cultural prejudices and worldviews of the dominant group in their country, with only a minority revealing any real transformation of attitudes or consciousness. It has been true of slavery and racism, classism and consumerism and issues of immigration and health care for the poor.", "The public health of five million children should not be left to luck or chance.", "Every day I wake up and I lay in bed counting my blessings and saying my prayers for how fortunate I am to have great fans and health and family.", "Change the way we all talk to each other about our mental health.", "All those spices and herbs in your spice rack can do more than provide calorie-free, natural flavorings to enhance and make food delicious. They're also an incredible source of antioxidants and help rev up your metabolism and improve your health at the same time.", "Having insurance doesn't guarantee good health outcomes, but it is a critical factor.", "We can make a commitment to promote vegetables and fruits and whole grains on every part of every menu. We can make portion sizes smaller and emphasize quality over quantity. And we can help create a culture - imagine this - where our kids ask for healthy options instead of resisting them.", "Cheerfulness is the best promoter of health and is as friendly to the mind as to the body.", "In order to lead a country or a company, you've got to get everybody on the same page and you've got to be able to have a vision of where you're going. America can't have a vision of health care for everybody, green economy, regulations - can't have a bunch of piece-meal activities. It's got to have a vision.", "Engaged, enthusiastic, and loyal employees are pivotal drivers of growth and health in any organization.", "Issues relating to global health and sustainability must stay high on the agenda if we are to cope with an ageing and ever-increasing population, with growing pressure on resources, and with rising global temperatures. The risks and dangers need to be assessed and then confronted.", "No matter what is happening in life or in the world - war, natural disaster, poor health, pain, the death of loved ones - if existence is filled with art, music and literature, life will be fulfilling, a joy.", "The war on terrorism has made national security a legitimate concern, and a rising deficit, changes brought on by globalization and even the price of oil have thrown the nation's economic health into question.", "Health is the soul that animates all the enjoyments of life, which fade and are tasteless without it.", "The winners in life treat their body as if it were a magnificent spacecraft that gives them the finest transportation and endurance for their lives.", "I seem to be thinking rationally again in the style that is characteristic of scientists. However, this is not entirely a matter of joy as if someone returned from physical disability to good physical health.", "We have a list of human rights - right to food, right to shelter, right to health, right to education, many such items which are considered and accepted as bill of rights. These are to be insured to people. So all nations, all societies try to do that.", "The real pride, the real present, is your health and your longevity. My whole career, I have never done anything where competition was involved with weight loss.", "I've never made a penny being a doctor, so that makes it not a job. My sense of a doctor is that one is a presence caring for health. So I'm never not a doctor. People call me from all over the world who are hurting, and I care for them. Chatting is what more people want than anything.", "We're losing biodiversity globally at an alarming rate, and we need a cornucopia of different plants and animals, for the planet's health and our own.", "All the evidence shows very clearly that if you are a member of a trade union you are likely to get better pay, more equal pay, better health and safety, more chance to get training, more chance to have conditions of work that help if you have caring responsibilities... the list goes on!", "I take the view that anything you can do to relieve suffering or improve human health will usually be widely accepted by the public - that is to say, if cloning actually turned out to be solving some problems and was useful to people, I think it would be accepted.", "The real cure for what ails our health care system today is less government and more freedom.", "I've spent half my life in gyms, if not more, and I love physical fitness and health; couple that with the fact that I love for people to be healthy, whether it's mentally, physically, or emotionally, and it's just a great opportunity for me to do something I love and have an impact on people's health.", "Connectivity enables transparency for better government, education, and health.", "There's a big difference between France and the U.S. In the U.S., immigrants must work to live. In France, they're taken care of by public finances. In France, there are millions of unemployed people already. We cannot house them, give them health care, education... finance people who keep coming and coming.", "In the 1940s, cigarettes would be shown in classy situations, endorsed by celebrities - real A-list Hollywood stars in America - the ads would make claims about tobacco quality or manufacturing science and, bizarrely, some brands had what almost amounted to health claims.", "It's quite amazing to me, as I walk around a supermarket or a health food shop, to observe the number of Fairtrade choices: not just staples such as coffee, tea, fresh fruits and rice, but cocoa and chocolate, herbs and spices, honey, ice cream, and jams.", "Whatever we do, it is definitely time that we reboot the health care reform attempt. It's time to completely start over.", "All Americans should have access to quality, affordable health care.", "At FDA, our mission is to promote and protect the health of the public. As commissioner, I've worked hard to galvanize people around that idea. I want employees to be thinking about the unique and essential contribution they are making to our mission.", "Great amount of scientific research is there to show that health is better because transcendental meditation deals with consciousness, and consciousness is the basic value of all the physical expressions. The entire creation is the expression of consciousness.", "I saw many people who had advanced heart disease and I was so frustrated because I knew if they just knew how to do the right thing, simple lifestyle and diet steps, that the entire trajectory of their life and health would have been different.", "Because sanitation has so many effects across all aspects of development - it affects education, it affects health, it affects maternal mortality and infant mortality, it affects labor - it's all these things, so it becomes a political football. Nobody has full responsibility.", "Our health care system squanders money because it is designed to react to emergencies. Homeless shelters, hospital emergency rooms, jails, prisons - these are expensive and ineffective ways to intervene and there are people who clearly profit from this cycle of continued suffering.", "I learned very early that our health is always impaired by some excess either of food or abstinence, and I never had any physician except myself.", "You can't have public health without working with the public sector. You can't have public education without working with the public sector in education.", "It's like, hmm, there's people with $2000 weaves that could have bought health care with that weave money. They don't have insurance. People want what they want. And I guess that is a reason we have this big credit card problem and a lot of these foreclosures.", "There should not be one new dime in tax breaks for millionaires and billionaires as long as millions of children in America are poor, hungry, uneducated and without health coverage.", "From wearable sensors to video game treatments, everyone seems to be looking to technology as the next wave of innovation for mental health care.", "The return on investment in global health is tremendous, and the biggest bang for the buck comes from vaccines. Vaccines are among the most successful and cost-effective health investments in history.", "New vaccines are being developed all the time, which could save many more lives and dramatically improve people's health. And this goes beyond the traditional burden of childhood infectious diseases.", "God can cause opportunity to find you. He has unexpected blessings where you suddenly meet the right person, or suddenly your health improves, or suddenly you're able to pay off your house. That's God shifting things in your favor.", "Personal health is related to self-control and to the worship of life in all its natural beauty - self-control bringing with it happiness, renewed youth, and long life.", "TV does not care about you or what happens to you. It's downright bad for your health now, and that's not a far-out concept. I think watching the TV news is bad for you. It is bad for your physical health and your mental health.", "A wise man should consider that health is the greatest of human blessings, and learn how by his own thought to derive benefit from his illnesses.", "Walking is magic. Can't recommend it highly enough. I read that Plato and Aristotle did much of their brilliant thinking together while ambulating. The movement, the meditation, the health of the blood pumping, and the rhythm of footsteps... this is a primal way to connect with one's deeper self.", "America's health care system is in crisis precisely because we systematically neglect wellness and prevention.", "I've always had a burning desire to help people and make a difference in the world. I didn't know how I could do that in modelling when it can be such a fake world. But my dad told me I could make a difference by being true to myself and teaching people what I've learnt about spirituality, health and nutrition.", "In the first three years of life, the foundations of physical and also of psychic health are laid. In these years, the child not only increases in size but passes through great transformations. This is the age in which language and movement develop. The child must be safeguarded in order that these activities may develop freely.", "Good humor is the health of the soul, sadness is its poison.", "Never continue in a job you don't enjoy. If you're happy in what you're doing, you'll like yourself, you'll have inner peace. And if you have that, along with physical health, you will have had more success than you could possibly have imagined.", "I loved clinical practice, but in public health, you can impact more than one person at a time. The whole society is your patient.", "The health of the eye seems to demand a horizon. We are never tired, so long as we can see far enough.", "It's one thing to show your love for someone when everything is going fine and life is smooth. But when the 'in sickness and in health' part kicks in and sickness does enter your lives, you're tested. Your resilience is tested.", "I think the healthy way to live is to make friends with the beast inside oneself, and that means not the beast but the shadow. The dark side of one's nature. Have fun with it and you know, is to accept everything about ourselves.", "When cattle ranchers clear rain forests to raise beef to sell to fast-food chains that make hamburgers to sell to Americans, who have the highest rate of heart disease in the world (and spend the most money per GNP on health care), we can say easily that business is no longer developing the world. We have become its predator.", "We should be concerned not only about the health of individual patients, but also the health of our entire society.", "The biggest public health challenge is rebuilding health systems. In other words, if you look at cholera or maternal mortality or tuberculosis in Haiti, they're major problems in Haiti, but the biggest problem is rebuilding systems.", "When you take the time to cleanse your physical body of accumulated stress and toxicity, you are rewarded with increased vitality and optimal health.", "I am in very good health. I've never felt better.", "Unhealthy eating habits cause major health problems, such as diabetes and heart disease, and can also lead to food insecurity, disrupted eating patterns, and low self-esteem.", "I am confident that nobody... will accuse me of selfishness if I ask to spend time, while I am still in good health, with my family, my friends and also with myself.", "America has the best doctors, the best nurses, the best hospitals, the best medical technology, the best medical breakthrough medicines in the world. There is absolutely no reason we should not have in this country the best health care in the world.", "Studies have shown that inmate participation in education, vocational and job training, prison work skills development, drug abuse, mental health and other treatment programs, all reduce recidivism, significantly.", "Man does not live by soap alone; and hygiene, or even health, is not much good unless you can take a healthy view of it or, better still, feel a healthy indifference to it.", "What do we have for veterans? Government-run health care. I understand that. Congressmen and senators... they get five choices of government-run health care. Why should a congressman and senator get anything more than a regular citizen does? Why are they privileged and the rest of us aren't?", "Well, I think that abstinence has its place as part of a comprehensive health and sex education curriculum. It would be wrong to exclude abstinence from a health curriculum, because there are some potentially very serious ramifications for early sexual activity.", "As long as I have health and strength, I will gladly work all my days.", "Attention to health is life's greatest hindrance.", "Because the biological mechanisms that affect our health and well-being are so dynamic, when people change their diet and lifestyle, they usually feel so much better, so quickly; it reframes the reason for changing from fear of dying to joy of living. Also, the support that patients give each other is a powerful motivator.", "The health of a democratic society may be measured by the quality of functions performed by private citizens.", "The essence of global health equity is the idea that something so precious as health might be viewed as a right.", "A person's health isn't generally a reflection of genes, but how their environment is influencing them. Genes are the direct cause of less than 1pc of diseases: 99pc is how we respond to the world.", "There is one consolation in being sick; and that is the possibility that you may recover to a better state than you were ever in before.", "We can be thankful to a friend for a few acres, or a little money; and yet for the freedom and command of the whole earth, and for the great benefits of our being, our life, health, and reason, we look upon ourselves as under no obligation.", "The very elements of what constitutes good nursing are as little understood for the well as for the sick. The same laws of health or of nursing, for they are in reality the same, obtain among the well as among the sick.", "Obviously, there is much similarity among the challenges of transgender people and all women - from health care to harassment to discrimination in the workplace.", "I made a commitment to completely cut out drinking and anything that might hamper me from getting my mind and body together. And the floodgates of goodness have opened upon me - spiritually and financially.", "I ate no butcher's meat, lived chiefly on fruits, vegetables, and fish, and never drank a glass of spirits or wine until my wedding day. To this I attribute my continual good health, endurance, and an iron constitution.", "As I mentioned previously, the tools that allow for optimum health are diet and exercise.", "For most women, including women who want to have children, contraception is not an option; it is a basic health care necessity.", "To get away from poverty, you need several things at the same time: school, health, and infrastructure - those are the public investments. And on the other side, you need market opportunities, information, employment, and human rights.", "Mama grizzlies mate later than other bears. They have two cubs instead of four. They wait four years - about twice as long as other bears - between having cubs. And after they're pregnant, if winter is hard or their health is not good or the food supply is uncertain, they re-absorb the embryo into their body.", "Think of an economy where people could be an artist or a photographer or a writer without worrying about keeping their day job in order to have health insurance.", "The feeling of insecurity is inimical to our sense of wellbeing, as it causes anxiety and stress, which harms our physical and mental health. It is no surprise then that, according to some surveys, workers across the world value job security more highly than wages.", "Whether it's making sure that families have access to quality health care and child care, or making sure that our children receive the best educational opportunities we can give them, we must remain committed to these needs because our children are our future.", "I'm not into animal rights. I'm only into animal welfare and health. I've been with the Morris Animal Foundation since the '70s. We're a health organization. We fund campaign health studies for dogs, cats, lizards and wildlife. I've worked with the L.A. Zoo for about the same length of time. I get my animal fixes!", "So I can't show you how, exactly, health care is a basic human right. But what I can argue is that no one should have to die of a disease that is treatable.", "When you feel great, you emanate a certain energy that translates as beautiful. I don't care if you have the standard beauty or not; it's that X-factor that comes through, and the basis of that is good health.", "I did not become a vegetarian for my health, I did it for the health of the chickens.", "What's happened with the over-the-counter birth control issue is that the Democrats didn't see it coming. They think that they've got a monopoly on talking to women from the waist down. Anything that has to do with reproduction and birth control and abortion - they call it women's health, then they call it women's issues.", "Nothing matters more than your health. Healthy living is priceless. What millionaire wouldn't pay dearly for an extra 10 or 20 years of healthy aging?", "If we vote to Leave and take back control, all sorts of opportunities open up. Including doing new free trade deals around the world, restoring Britain's seat on all sorts of international bodies, restoring health to our democracy and belief to our democracy.", "America's doctors, nurses and medical researchers are the best in the world, but our health care system is broken.", "In the United States, where we have more land than people, it is not at all difficult for persons in good health to make money.", "I have the body of an eighteen year old. I keep it in the fridge.", "It has had a tremendous impact on my life, more than on the life of most Prize winners, because I was in an unusual situation. I was unemployed at the time. I was in good health, but I had reached the age of 66 and beginning to get social security, but I didn't have much of that. I had many years of unemployment before me.", "Healthy people are those who live in healthy homes on a healthy diet; in an environment equally fit for birth, growth work, healing, and dying... Healthy people need no bureaucratic interference to mate, give birth, share the human condition and die.", "We need strong public health institutions to respond to any challenge. We need to deal with critical infrastructure. The reality is that very little money has flowed to communities to help our first responders; to help our hospitals; to help the public health infrastructure.", "Mr. Speaker, our Nation must no longer be complacent about underage drinking and its alarming consequences. We must bring this national public health crisis out of the shadow and into the bright light of a national priority.", "It is time that we take control and find a way to curtail the explosive costs of health care. Small businesses deserve a chance to channel these funds toward other needs, such as expanding and creating more jobs for the economy.", "The way you think, the way you behave, the way you eat, can influence your life by 30 to 50 years.", "If you think health care is expensive now, just wait 'til it's free.", "Cynicism is humor in ill health.", "Ultimately, health care fails the most basic test. It's not organized around the needs of the patient.", "I got sent to a health camp when I was about 6 years old, and we all had to wear the same starchy blue uniform. The lady who took care of me after school knit me a burgundy sweater. It was the only thing that gave me any individuality.", "For whatever reason, maybe it's because of my story, but people associate Livestrong with exercise and physical fitness, health and lifestyle choices like that.", "The signs of climate change are visible across the nation, from the drought-stricken fields of Central California to the flooded streets of Michigan. Extreme weather is turning people's lives upside down and costing communities millions of dollars in damaged infrastructure and added health care costs.", "Every single dollar spent lobbying a legislator on behalf of oil and gas is a toxic dollar that undermines public health and safety laws that protect Americans. That's contamination of the political system.", "The carrying power of a bridge is not the average strength of the pillars, but the strength of the weakest pillar. I have always believed that you do not measure the health of a society by GNP but by the condition of its worst off.", "I've always been interested in public health approaches because it seems to me we have this yearning for silver bullets, and that is not in fact how change comes about. Change comes through silver buckshot - a lot of little things that achieve results. That's a classic public health approach.", "True health care reform cannot happen in Washington. It has to happen in our kitchens, in our homes, in our communities. All health care is personal.", "We will always make sure player health and safety is our No. 1 priority in the NFL.", "Alaska is what happens when Willy Wonka and the witch from Hansel and Gretel elope, buy a place together upstate, renounce their sweet teeth, and turn into health fanatics.", "The ingredients of health and long life, are great temperance, open air, easy labor, and little care.", "It's so important to have a great relationship with your physician. It's one of those essential relationships that I find to be as important to nurture as any other relationship in your life. Without your health, you have nothing.", "I have long recognized a link between fitness and mental health and I think we need to encourage young people to take part in sports and team activities because we know it has such positive results.", "What we know from World War I is that some of our troops had acute symptoms of exposure to chemicals, had bad health and died because of chemical exposure in World War I.", "'Tis healthy to be sick sometimes.", "We have to design a health delivery system by actually talking to people and asking, 'What would make this service better for you?' As soon as you start asking, you get a flood of answers.", "I hope for your help to explore and protect the wild ocean in ways that will restore the health and, in so doing, secure hope for humankind. Health to the ocean means health for us.", "Human rights, race relations, gender politics, health care, and foreign policy - it's a lot to keep track of, and yet all of these things affect us in our daily lives. Making sense of everything requires meticulous unpacking of feelings, delicate navigation of social norms, and a community of love to help along the way.", "Water and sanitation has not had the same kind of champion that global health, and even education, have had.", "When mothers earn their fair share, young children have greater access to quality health care, educational opportunities, and safe communities. By ending the wage gap, we will help ensure that every child can achieve his or her God-given potential.", "Texas is a great place to be rich and a terrible place to be poor. It's got the highest percentage of people without health insurance in the country. If you get injured on the job, good luck getting workers' comp. And God help you if you're poor and mentally ill.", "Policy is no longer being written by politicians accountable to the American public. Instead, policies concerning the defense budget, deregulation, health care, public transportation, job training programs, and a host of other crucial areas are now largely written by lobbyists who represent mega corporations.", "An inspiration - a long, deep breath of the pure air of thought - could alone give health to the heart.", "We cannot seek or attain health, wealth, learning, justice or kindness in general. Action is always specific, concrete, individualized, unique.", "General Motors spends more on health care than steel.", "The real truth is that the Obama administration is professional at bullying, as we have witnessed with ACORN at work during the presidential campaign. It seems to me they are sending down their bullies to create fist fights among average American citizens who don't want a government-run health care plan forced upon them.", "My main mistake was to have made an ancient people advance by forced marches toward independence, health, culture, affluence, comfort.", "It's been a long road back to health and fitness for me. I am just glad to have been given the opportunity to do what I love most.", "I turned into a workaholic to the point of where my health was in jeopardy.", "Cerner's focus over the last 20 years has been to provide healthcare, predominately healthcare providers, with advanced clinical and management information systems. Our mission is to connect the appropriate persons, knowledge, and resources at the appropriate time and location to achieve the optimal health outcome.", "The abundance of cheap food with low nutritional value in the Western diet has wreaked havoc on our health; in America, one third of children and two thirds of adults are overweight or obese and are more likely to develop diabetes and cardiovascular disease.", "I'm grateful for everything. I'm grateful for my health, and I'm so grateful for the love in my life.", "A poet could write volumes about diners, because they're so beautiful. They're brightly lit, with chrome and booths and Naugahyde and great waitresses. Now, it might not be so great in the health department, but I think diner food is really worth experiencing periodically.", "Obsession with the market seem to prevent ministers looking at the huge problem and all its ramifications in health, education and employment that come from the housing insecurity that too many face.", "It is inexcusable that the richest country in the world does not take care of all of its people. We don't consider ourselves idealistic; we're thoughtfully trying to make a beautiful health care model.", "People have criticized me for seeming to step out of my professional role to become undignifiedly political. I'd say it was belated realization that day care, good schools, health insurance, and nuclear disarmament are even more important aspects of pediatrics than measles vaccine or vitamin D.", "If we cannot provide excellent educational opportunities to all children, safe communities, quality health coverage, or robust and fair avenues towards wealth creation, then our nation will increasingly be in peril.", "A girl child who is even a little bit educated is more conscious of family planning, health care and, in turn, her children's own education.", "No matter how old you are, no matter how much you weigh, you can still control the health of your body.", "I've always had good energy; I've always had good health.", "Age does not depend upon years, but upon temperament and health. Some men are born old, and some never grow so.", "Today, diabetes is now epidemic, according to the Centers for Disease Control, the National Institutes of Health, the American Diabetes Association and other national healthcare leaders.", "Too many Americans who are uninsured or under-insured do not receive regular checkups because they can't afford coverage or their insurance doesn't cover enough of the costs. The lack of preventive care results in countless emergency room visits and health care disasters for families.", "The 20th-century ulcer epidemic was a sign of good health in American people - good diet, strong acidity and healthy immune response actually make ulcers more likely. That's why businessmen eating giant T-bone steaks were prone to ulcers.", "If you can be well without health, you may be happy without virtue.", "As musicians and artists, it's important we have an environment - and I guess when I say environment, I really mean the industry, that really nurtures these gifts. Oftentimes, the machine can overlook the need to take care of the people who produce the sounds that have a lot to do with the health and well-being of society.", "There is a consensus of willing leaders from both parties coalescing around the right way forward in health care. Reform should address government-imposed inequities and barriers to true choice and competition.", "My good health is due to a soup made of white doves. It is simply wonderful as a tonic.", "Health food makes me sick.", "The drug war has been a war where the direct casualties have primarily been America's poor; America's minorities; and often, unfortunately, America's vulnerable, in terms of people with disease and addiction and mental health.", "You don't train someone for all of those years of medical school and residency, particularly people who want to help others optimize their physical and psychological health, and then have them run a claims-processing operation for insurance companies.", "Raising taxes is the last thing we should do amid the weakest economic recovery since World War II. Unfortunately, even if we avoid the full 'Taxmageddon' scenario, President Obama's health care law also contains a new surtax on investment that will take effect in 2013.", "The most common objection that I hear to walking as exercise is that it's too easy, that only sweaty, strenuous activity offers real benefits. But there is abundant evidence that regular, brisk walking is associated with better health, including lower blood pressure, better moods and improved cholesterol ratios.", "New Year's Eve to Valentine's Day is our peak season, and in many ways, Valentine's Day is our Christmas. Everybody in the world makes the same three New Year's resolutions: health, career and money, and love.", "A healthy human environment is one in which we try to make sense of our limits, of the accidents that can always befall us and the passage of time which inexorably changes us.", "It's never too late to take your heart health seriously and make it a priority.", "It is time to end the discrimination against people who need treatment for chemical addiction. It is time for Congress to deal with our Nation's number one public health problem.", "From exam grading to health education to professional training to democratic participation, paths towards self-realization and success in the world are often daunting and obscure: journeys only the privileged feel confident setting off along.", "Access to basic quality health care is one of the most important domestic issues facing our nation.", "Competition makes things come out right. Well, what does that mean in health care? More hospitals so they compete with each other. More doctors compete with each other. More pharmaceutical companies. We set up war. Wait a minute, let's talk about the patient. The patient doesn't need a war.", "The world has been experiencing a whole pattern of auto-destruction, whether in environmental disasters like Chernobyl or health disasters like AIDS.", "Meat consumption is just as dangerous to public health as tobacco use... It's time we looked into holding the meat producers and fast-food outlets legally accountable.", "Many of the received models of modern architecture and planning owe their ultimate origin to the building code and public health reform movements of the second half of the 19th century.", "To get rich never risk your health. For it is the truth that health is the wealth of wealth.", "The truth is, in order to get things like universal health care and a revamped education system, then someone is going to have to give up a piece of their pie so that someone else can have more.", "I believe in universal health care. And I am not afraid to say so.", "Health is certainly extremely important, and we've done a number of things at Facebook to help improve global health and work in that area, and I am excited to do more there, too. But the reality is that it's not an either-or. People need to be healthy and be able to have the Internet as a backbone to connect them to the whole economy.", "Man's constitution is so peculiar that his health is purely a negative matter. No sooner is the rage of hunger appeased than it becomes difficult to comprehend the meaning of starvation. It is only when you suffer that you really understand.", "It's bizarre that the produce manager is more important to my children's health than the pediatrician.", "Since beginning my work in areas like addiction, for example, I have seen time and time again that the roots of poor mental health in adulthood are almost always present in unresolved childhood challenges.", "Hydraulic fracturing requires massive amounts of water. Disposing of the toxic wastewater, as well as accidental spills, can contaminate drinking water and harm human health.", "Part of me thinks that innovation, real innovation in health care delivery, needs to happen from the bottom to the top.", "The root cause of the looming energy problem - and the key to easing environmental, economic and religious tensions while improving public health - is to address the unending, and unequal, growth of the human population. And the one proven way to reduce fertility rates is to empower young women by educating them.", "Health consists of having the same diseases as one's neighbors.", "My Dad is my hero. He's 85 now and he is in great health. He is handsome and strong. He has an incredible moral and ethical backbone. I couldn't have been luckier with my parents.", "As women slowly gain power, their values and priorities are reshaping the agenda. A multitude of studies show that when women control the family funds, they generally spend more on health, nutrition, and education - and less on alcohol and cigarettes.", "My daily schedule is quite hectic, but I have to put my health first in order to be the best mom and wife I can be.", "As one ages, eventually, no matter what regime you've followed, no matter how fiercely you've fought the fight, good health becomes harder to maintain. It may disappear overnight or simply dwindle, but with every year that passes, the odds shorten.", "I've got a cure for mental health issue. Spank your children more.", "I believe that how you feel is very important to how you look - that healthy equals beautiful.", "People get caught up in the idea that health is just what you look like and what you eat, but your health is physical, emotional and mental. Who's to say eating that bowl of ice cream after training isn't going to help me psychologically and emotionally?", "I've made a promise to myself to be a 100% healthy person if nothing else.", "Taste is developed by the diversity of the products one can sample. I think our children today may be missing an education about food. We must teach them to know their cuisine and to know the equilibrium of nourishment. That is very important for health.", "We don't have enough people going into those fields and there is a high burnout rate in some health care professions, so it is very important that we get more people into the pipeline right now.", "We need to honor our troops who served and show our support by giving our men and women who served the best health care, the best educational opportunities, and the best job training available. They deserve nothing less.", "We control health and pathogenicity by complex multi-speciated relationships through symbiosis and synergy. Portable shelters for livestock, along with electric fencing, insure hygienic and sanitary housing and lounging areas, not to mention clean air, sunshine, and exercise.", "Laziness works. And the simple way to incorporate its health benefits into your life is simply to take a nap.", "If my colleagues stop eating donuts and are more active, it saves me money on next year's insurance premium, and I get to work with people who have more energy and creativity each day. Yet most organizations fail to make health a cultural priority. Instead, they treat healthcare like any other expense.", "We seek to protect and preserve life for life's own sake in everything from our most fundamental laws of homicide to our road traffic regulations to our largest governmental programs for health and social security.", "We are involved in youth testing internationally. We want to try to prove without a shadow of a doubt the relationship between physical fitness and health, not just physical fitness and ability to perform.", "What public health really is is a trust. That's why I used the term 'Betrayal of Trust' as the title of my book. It's a trust between the government and the people.", "If we don't figure out a way to create equity, real equity, of opportunity and access, to good schools, housing, health care, and decent paying jobs, we're not going to survive as a productive and healthy society.", "But the real secret to lifelong good health is actually the opposite: Let your body take care of you.", "Doing all we can to combat climate change comes with numerous benefits, from reducing pollution and associated health care costs to strengthening and diversifying the economy by shifting to renewable energy, among other measures.", "Remove the predators, and the whole ecosystem begins to crash like a house of cards. As the sharks disappear, the predator-prey balance dramatically shifts, and the health of our oceans declines.", "When you get older, your health becomes important to you, things start breaking down, you've always got a different ache or pain.", "I'm healthy as can be - not an ache or a pain. A lot of my prayer is thanking the Lord that I am healthy. I pray for long life and good health.", "I'm a clown, which could be a public health role. I'm really interested in moving our society away from a society needing Xanax and Prozac, and that is really feeling depressed, to one that is celebrating, and so I find just walking around in colorful clothes, people smile.", "Mushrooms are miniature pharmaceutical factories, and of the thousands of mushroom species in nature, our ancestors and modern scientists have identified several dozen that have a unique combination of talents that improve our health.", "If we get our self-esteem from superficial places, from our popularity, appearance, business success, financial situation, health, any of these, we will be disappointed, because no one can guarantee that we'll have them tomorrow.", "Individuals will achieve healthier lifestyles when prevention and wellness programs are accessible and available in their workplace, through their health provider, and in their communities.", "Together with open conversations and greater understanding, we can ensure that attitudes for mental health change and children receive the support they deserve.", "Health and fitness is who I am. It's what I do.", "The rise of childhood obesity has placed the health of an entire generation at risk.", "The wish for healing has always been half of health.", "A dark house is always an unhealthy house, always an ill-aired house, always a dirty house. Want of light stops growth and promotes scrofula, rickets, etc., among the children. People lose their health in a dark house, and if they get ill, they cannot get well again in it.", "Almost every economist agrees that the American health care system is unsustainable. Medical care is so expensive that it is busting all of our budgets - government, business, and personal. Eventually, the medical price bubble will pop. What, then, are the alternatives?", "Health to the ocean means health for us.", "The defeat of Obamacare will come from the realization that the very idea of a government-administered health care system is absurd... and by people opting out of the system and developing workarounds.", "Regularity in the hours of rising and retiring, perseverance in exercise, adaptation of dress to the variations of climate, simple and nutritious aliment, and temperance in all things are necessary branches of the regimen of health.", "In 1995, world military spending totaled nearly $800 billion. If we redirected just $40 billion of those resources over the next 10 years to fighting poverty, all of the world's population would enjoy basic social services, such as education, health care, nutrition, reproductive health, clean water and sanitation.", "I think that age as a number is not nearly as important as health. You can be in poor health and be pretty miserable at 40 or 50. If you're in good health, you can enjoy things into your 80s.", "I pray God may preserve your health and life many years.", "The fabric of North Carolina and what makes our state so special is our families and our common desire for a brighter future for our children. No matter what your family looks like, we all want the same thing for our families - happiness, health, prosperity, a bright future for our children and grandchildren.", "Mental health can be just as important as physical health - and major depression is one of the most commonly diagnosed mental illnesses.", "Modern medicine is a negation of health. It isn't organized to serve human health, but only itself, as an institution. It makes more people sick than it heals.", "Our progress against malaria is impressive. But vigilance remains a critical ingredient to protect the health of all people.", "Happiness is nothing but good health and freedom, and money is the single best way you can buy your freedom.", "The goal of my diet-style is eating for optimal health and longevity. What greater benefit could there be than living healthfully and actively into old age with no dependence on medications and almost no risk of heart disease, diabetes or dementia?", "Lord save us all from old age and broken health and a hope tree that has lost the faculty of putting out blossoms.", "I seem to be thinking rationally again in the style that is characteristic of scientists. However, this is not entirely a matter of joy, as if someone returned from physical disability to good physical health. One aspect of this is that rationality of thought imposes a limit on a person's concept of his relation to the cosmos.", "There's a lot of people in this world who spend so much time watching their health that they haven't the time to enjoy it.", "Every three seconds in the developing world, a child dies needlessly due to lack of basic health care and other things we all take for granted.", "I have argued for years that we do not have a health care system in America. We have a disease-management system - one that depends on ruinously expensive drugs and surgeries that treat health conditions after they manifest rather than giving our citizens simple diet, lifestyle and therapeutic tools to keep them healthy.", "I admired the way McCain worked on campaign finance reform. I admired the way Nancy Pelosi stiffened the Democrats' spine during the health care debate. I admire the way Barack Obama has raised a dog in the White House without ever putting it on the roof of the car for a vacation drive.", "A good job is more than just a paycheck. A good job fosters independence and discipline, and contributes to the health of the community. A good job is a means to provide for the health and welfare of your family, to own a home, and save for retirement.", "A life coach does for the rest of your life what a personal trainer does for your health and fitness.", "What a brutish master sin is, taking the joy from one's life, stealing money and health, giving promise of tomorrow's pleasures, and finally leading one onto the rotten planking that overlies the mouth of the pit.", "Looking after my health today gives me a better hope for tomorrow.", "I do all I can to maintain good health. I eat mostly plants, as Michael Pollan would say. I get a lot of exercise. I lead a purposeful daily life. I stay current with the dentist. I made the formative decision of where to live over thirty years ago when I settled in a 'main street' small town in upstate New York.", "I believe that parents need to make nutrition education a priority in their home environment. It's crucial for good health and longevity to instill in your children sound eating habits from an early age.", "Steroids can seem necessary to compete at the highest levels, and the quick rewards can outweigh the long term consequences to the user's health.", "Smoking is the now the principal avoidable cause of premature death in Britain. It hits the worst off people hardest of all. Smoking is one of the principal causes of the health gap which leads to poorer people being ill more often and dying sooner.", "There's a need for accepting responsibility - for a person's life and making choices that are not just ones for immediate short-term comfort. You need to make an investment, and the investment is in health and education.", "The key to the future in an aging society is not found in increasing just our life span; we need to increase our health span at the same time.", "If you're working out in front of a mirror and watching your muscles grow, your ego has reached a point where it is now eating itself. That's why I believe there should be a psychiatrist at every health club, so that when they see you doing this, they will take you away for a little chat.", "Once brave politicians and others explain the war on drugs' true cost, the American people will scream for a cease-fire. Bring the troops home, people will urge. Treat drugs as a health problem, not as a matter for the criminal justice system.", "You don't have to be a wreck. You don't have to be sick. One's aim in life should be to die in good health. Just like a candle that burns out.", "In poor countries, we still need better ways to measure the effectiveness of the many government workers providing health services. They are the crucial link bringing tools such as vaccines and education to the people who need them most. How well trained are they? Are they showing up to work?", "The chief condition on which, life, health and vigor depend on, is action. It is by action that an organism develops its faculties, increases its energy, and attains the fulfillment of its destiny.", "To be stupid, selfish, and have good health are three requirements for happiness, though if stupidity is lacking, all is lost.", "I remember the first pangs of stress arriving at the end of school. Once I graduated I had to get a full-time job, worry about health insurance, saving money, paying rent - things I'd never thought about before.", "Knowing that we can be loved exactly as we are gives us all the best opportunity for growing into the healthiest of people.", "I'm not suggesting that social scientists stop teaching and investigating classic topics like monopoly power, racial profiling and health inequality. But everyone knows that monopoly power is bad for markets, that people are racially biased and that illness is unequally distributed by social class.", "But reducing harmful emissions, abating our dependence on foreign oil and developing alternative renewable energy sources have benefits that go beyond environmental health, they improve personal health, enhance national security and encourage our nation's economic viability.", "Care for life and physical health, with due regard for the needs of others and the common good, is concomitant with respect for human dignity.", "A tremendous amount of needless pain and suffering can be eliminated by ensuring that health insurance is universally available.", "The FDA serves a real purpose: To protect public health.", "I pray for forgiveness. For help and guidance. To be a better person. For the health of my family. For the world to be a better place.", "I never could have achieved the success that I have without setting physical activity and health goals.", "Law has become a business. Health care has become a business. Unfortunately, politics has also become a business. That really undermines society.", "I don't think healthcare's a right. The only right you have is the ability to go out on an even playing field and work, and then purchase health insurance, or whatever it is.", "Property may be destroyed and money may lose its purchasing power; but, character, health, knowledge and good judgement will always be in demand under all conditions.", "Since the tragedy at Sandy Hook Elementary School three years ago, we have lost over 90,000 Americans to gun violence. This is a manmade crisis that needs to be treated as the public health epidemic it has become.", "Redemption basically is about holistic health, if you want to translate it into modern parlance. What I suggest - based on the Christian tradition but not often preached - is that you can't enter into the fullness of the Pascal mystery of the redemption unless there is a radical transformation of motivation within you.", "You know, true love really matters, friends really matter, family really matters. Being responsible and disciplined and healthy really matters.", "Maternal health remains a staggering challenge, particularly in the developing world. Globally, a woman dies from complications in childbirth every minute.", "As a black person in America, I am twice as likely as a white person to live in an area where air pollution poses the greatest risk to my health. I am five times more likely to live within walking distance of a power plant or chemical facility - which I do.", "As a father, physician and nurse, I have a special place in my heart for children, and I know the brief window of opportunity we have to teach them simple lessons that can lead to a lifetime of good health.", "We want to make sure that we incentivize the health care system to be designed to provide you the best quality health care possible.", "I do not think about being beautiful. What I devote most of my time to is being healthy.", "What some call health, if purchased by perpetual anxiety about diet, isn't much better than tedious disease.", "I was born on the other side of the tracks, in public housing in Brooklyn, New York. My dad never made more than $20,000 a year, and I grew up in a family that lost health insurance. So I was scarred at a young age with understanding what it was like to watch my parents lose access to the American dream.", "We have seen that two heads are better than one when dealing with a mental health problem.", "Of the five most important things in life, health is first, education or knowledge is second, and wealth is third. I forget the other two.", "Health insurance should be a given for every citizen.", "To make others less happy is a crime. To make ourselves unhappy is where all crime starts. We must try to contribute joy to the world. That is true no matter what our problems, our health, our circumstances. We must try. I didn't always know this, and am happy I lived long enough to find it out.", "I think public awareness of how good vaccines are for kids and how they are good for public health is a great idea.", "Older people shouldn't eat health food, they need all the preservatives they can get.", "A lot of people want to donate a kidney, but they're not in a position to because they have health issues of their own, and a lot of people need them. That's why the list is long and it takes a long time.", "If you are able to see the interrelatedness of mind and body, sensitivity towards your body becomes much sharper. Therefore, maintaining of good health also becomes easier.", "Since 1994, lawmakers on both sides of the aisle have considered it politically risky to offer a plan to fix America's broken health care system. The American public, though, has paid the price for this silence as health care costs skyrocketed, millions went uninsured, and millions more grappled with financial insecurity and hardship.", "And I believe that the best buy in public health today must be a combination of regular physical exercise and a healthy diet.", "Lucid dreaming has considerable potential for promoting personal growth and self-development, enhancing self-confidence, improving mental and physical health, facilitating creative problem solving and helping you to progress on the path to self-mastery.", "The early pioneers of both wellness and network marketing were motivated by the sense that it was possible to create a better life than the conventional routes offered - better personal health and better economic health, respectively. Now the 'alternatives' of yesterday have become the economic powerhouses of today and tomorrow.", "If nuclear power plants are safe, let the commerical insurance industry insure them. Until these most expert judges of risk are willing to gamble with their money, I'm not willing to gamble with the health and safety of my family.", "And so our goal on health care is, if we can get, instead of health care costs going up 6 percent a year, it's going up at the level of inflation, maybe just slightly above inflation, we've made huge progress. And by the way, that is the single most important thing we could do in terms of reducing our deficit. That's why we did it.", "It contributes greatly towards a man's moral and intellectual health, to be brought into habits of companionship with individuals unlike himself, who care little for his pursuits, and whose sphere and abilities he must go out of himself to appreciate.", "As long as your body is healthy and under control and death is distant, try to save your soul; when death is immanent what can you do?", "Pride and vanity, the opposites of humility, can destroy our spiritual health as surely as a debilitating disease can destroy our physical health.", "An enormous piece of the cost in our health care system today is driven by lifestyle decisions, and so we all have an effort to do better.", "Health is not a condition of matter, but of Mind.", "In my home state of Indiana, we prove every day that you can build a growing economy on balanced budgets, low taxes, even while making record investments in education and roads and health care.", "I have yet to meet members of a leadership team who I thought lacked the intelligence or the domain expertise required to be successful. I've met many, however, who failed to foster organizational health. Their companies were riddled with politics, various forms of dysfunction, and general confusion about their direction and mission.", "Reducing dietary salt is not only important for those who already have elevated blood pressure - limiting added salt is essential for all of us to remain in good health.", "If you want ideal health, you need to overcompensate and eat an excellent diet.", "Managers of hospitals over the years have been increasingly recruited from outside the health service, and although their experience of running a supermarket chain might allow them to balance the books, it does not mean they have any insight into how a ward should be managed and patients best served.", "Natural gas obviously brings with it a number of quality-of-life environmental benefits because it is a relatively clean-burning fuel. It has a CO2 footprint, but it has no particulates. It has none of the other emissions elements that are of concern to public health that other forms of power-generation fuels do have: coal, fuel oil, others.", "I used to work for the World Health Organisation in poor countries all over the world - Bangladesh, Korea, the Philippines and India. You learn a whole range of things about how other people are living and try to connect with them to gain an understanding of where they're coming from.", "Antibiotics are a very serious public health problem for us, and it's getting worse. Resistant microbes outstrip new antibiotics. It's an ongoing problem. It's not like we can fix it, and it's over. We have to fight continued resistance with a continual pipeline of new antibiotics and continue with the perpetual challenge.", "One lesson that every nation can learn from China is to focus more on creating village-level enterprises, quality health services and educational facilities.", "If you are young and you drink a great deal it will spoil your health, slow your mind, make you fat - in other words, turn you into an adult.", "The preservation of health is a duty. Few seem conscious that there is such a thing as physical morality.", "I have nightmares that I'm going to wake up, and everyone's driving a Prius and living in a condo, and we're all getting health insurance.", "Most single moms are very poor, uneducated, can't get a job, and if it weren't for government assistance, their kids would be starving to death and never have health care. And that's the story that we're not seeing, and it's unfortunate that we glorify and glamorize the idea of out of children wedlock.", "It's crazy to me that in this world of electronic medical records Walmart has so much information about how we shop, but no one has that information about our health. Why can't my doctor say, 'Wow, Anne, based on your lifestyle and behavior, you're five years from being diabetic.' But I can go to Target, and they know exactly what I'm going to buy.", "We are made in the image of God, and we need to put Spirit back into the equation when we want to improve our physical and our mental health.", "By themselves, genetically engineered crops will not end hunger or improve health or bolster the economies of struggling countries. They won't save the sight of millions or fortify their bones. But they will certainly help.", "America's health care system is the most complicated and expensive in the world.", "Insomnia is a very prevalent issue. It's a women's health issue, and I chose to talk about it because so many people have experienced it to varying degrees. For me, I'm doing great now, but it took a lot of work to figure out how to get back to sleep. I had to change some of my habits. I developed some pretty bad sleep ritual habits.", "As an American, you have a right to good health care that is effective, accessible, and affordable, that serves you from infancy through old age, that allows you to go to practitioners and facilities of your choosing, and that offers a broad range of therapeutic options.", "What I would like to see is sufficiently good education and health services being delivered to Aboriginal people so that they are prepared and ready to leave and join the economic mainstream if that's their choice.", "Of course, as consumers, we want cheap and good products; however, if these production processes are exceeding wastewater discharge standards and even causing heavy metal pollution, they will cause long-lasting damage to the ecological environment and public health.", "When your boss and colleagues care enough to invest in your health, it is good for you and the business.", "You can look in the mirror and find a million things wrong with yourself. Or you can look in the mirror and think, 'I feel good, I have my health, and I'm so blessed.' That's the way I choose to look at it.", "Fear is a question: What are you afraid of, and why? Just as the seed of health is in illness, because illness contains information, your fears are a treasure house of self-knowledge if you explore them.", "Those who enjoy their own emotionally bad health and who habitually fill their own minds with the rank poisons of suspicion, jealousy and hatred, as a rule take umbrage at those who refuse to do likewise, and they find a perverted relief in trying to denigrate them.", "You can't just take an aspirin and sit around and have 12 donuts and think, 'I took my aspirin so I'm not going to have a heart attack.' It's really important each person take personal responsibility for their health. You can't keep thinking that someone else is going to take care of it. You have to be part of the solution.", "The truth is women use contraception not only as a way to prevent unintended pregnancies, but also to improve their health and the health of their families. Increased access to contraception is directly linked to declines in maternal and infant mortality.", "If investments in banks fall, it is a tragedy, and people say, 'What are we going to do?' but if people die of hunger, have nothing to eat or suffer from poor health, that's nothing.", "Even the securest financial plan and the finest health coverage aren't enough to hold us steady when the challenges come... We need something more, something deeper and unshakeable, something that will see us through life's hard times.", "The Occupy movement did create spontaneously communities that taught people something: you can be in a supportive community of mutual aid and cooperation and develop your own health system and library and have open space for democratic discussion and participation. Communities like that are really important.", "I, poor creature, worn out with scribbling for my bread and my liberty, low in spirits and weak in health, must leave others to wear the laurels which I have sown, others to eat the bread which I have earned. A common case.", "Government is a health hazard. Governments have killed many more people than cigarettes or unbuckled seat belts ever have.", "I'm a health nut, but when I eat, I go hard. I'm a Buffalo wing magnet, a sandwich fanatic, a cheesesteak guy. But I'll only get a cheesesteak in Philadelphia. No one else does it right.", "Writing about joyful experiences for just three days can improve people's moods and decrease their visits to health centers a full three months later.", "Health care is one-sixth of our economy. If the government can control that, they can control just about everything. We need to understand what is going on, because there are much more economic models that can be used to give us good health care than what we have now.", "Writing is hard work and bad for the health.", "Truly affordable but high-quality health care tools and services are the only means by which quality health care can be provided to all.", "Medicine to produce health must examine disease; and music, to create harmony must investigate discord.", "Exuberant health is always, as such, sickness also.", "Do you suppose there is any living man so unreasonable that if he found himself stricken with a dangerous ailment he would not anxiously desire to regain the blessing of health?", "I've always wanted to be in the health and wellness business. I try to encourage people to live a healthy lifestyle.", "Sometimes people ask me how difficult the astronaut program was, but being in Sierra Leone, being responsible for the health of more than 200 people, seven days a week, 24 hours a day, 365 days a year, at age 26 - that prepared me to take on a lot of different challenges.", "Our philosophy is you need to give nonprofit money for health, nutrition, education, culture, and sports.", "Positive health means becoming whole-heartedly engaged with our own health care. It means not outsourcing our health to the health care system. It means getting rid of the fear and paralysis we too often feel, and instead cultivating a sense of agency.", "Whether it's by helping us search for health-related information, connecting us with doctors through online portals, or enabling us to store and retrieve our medical records online, the Internet is starting to show the promise it has to transform the way people interact with and improve their own health and wellness.", "The American Dream is not being dependent on the federal government for your health care, for your automobile, for your college education, for your student loan on and on and on.", "Learning to read and write changes lives; it means jobs, money, health, and dreams fulfilled.", "Inflation is taking up the poverty line, and poverty is not just economic but defined by way of health and education.", "Health is relative. There is no such thing as an absolute state of health or sickness. Everyone's physical, mental, and emotional condition is a combination of both.", "These are important reforms. Infrastructure, education, health, hospitals, closing the gap with indigenous Australians. Also the Apology to the first Australians. As Prime Minister of the country I am proud of each and every one of these achievements.", "Poverty is multidimensional. It extends beyond money incomes to education, health care, political participation and advancement of one's own culture and social organisation.", "No evidence compels the conclusion that the minimum required intake of any vitamin comes close to the optimum intake that sustains good health.", "In the case of maternal health care, you look at, well naturally, it's the mother who's the customer, who makes the decisions. But in truth, the mother in many areas, in certain parts of India, the mother has very little decision-making power at all. The real decision-maker is the mother-in-law.", "I used to drink tons of caffeine. Now I make smoothies with frozen berries and Green Vibrance health powder.", "A healthy love life is not and should not be the preserve of those in their 20s and 30s. It's important at all ages.", "Children whose parents return to study do much better at school. Offenders who persist with studies are much less likely to reoffend. The national mental health strategy recognises the important role adult learning can play for people recovering from mental illness.", "Pneumonia is a disease that often flies under the radar of not just the public but even the global health community. It kills more children under 5 years old every year than AIDS, malaria, and measles combined.", "Successful health reform must not just make health insurance affordable, affordable health insurance has to make health care affordable.", "The only reason I took steroids was for my health purposes. I did not take steroids to get any gain for any strength purposes.", "The Affordable Care Act's requirement that certain individuals pay a financial penalty for not obtaining health insurance may reasonably be characterized as a tax.", "Our system of private health insurance that fails to provide coverage to so many of our citizens also contributes to the double-digit health care inflation that is making America less competitive in the global economy.", "Countries that need monies so that they can provide health care and education and shelter to their people shouldn't have to repay debts that we knowingly lent to bad regimes long since gone; and all illegitimate debts - debts lent to these terrible dictators like Saddam Hussein, like Suharto, like Marcos - must also be canceled.", "It was one of the most exciting, perfect evenings of my life, my solo debut at Carnegie Hall. And knowing we were all there to raise money for Gay Men's Health Crisis made the evening an extraordinary experience.", "My mom was a rescue veterinarian, and I grew up helping her nurse injured animals back to health. Any deer hit by a car, fox caught in a trap, whatever it was that got hurt, everyone brought them to my mom.", "Today the demands are for even higher standards in the quality of care, for greater flexibility and convenience in treatment times, and for more prevention through screening and health checks.", "I really want to see good health care brought to all the people of Alabama at a reasonable cost.", "Investing in health will produce enormous benefits.", "When elected officials abandon our environment and ruin our natural resources, public health is endangered. I know the importance of providing a clean environment for our children; I have attended more than one funeral for a child who has died from an asthma attack.", "Health nuts are going to feel stupid someday, lying in hospitals dying of nothing.", "Using lots of fresh foods, fruits and vegetables, helps to keep the menu buoyant - I don't know if that's the right word, but it keeps a balance of freshness and health.", "The more you look into health and health inequalities, you realize that a lot of it is not due to a particular disease - it's really linked to underlying societal issues such as poverty, inequity, lack of access to safe drinking water and housing. And these are all the things we focus on at CARE.", "Restoring responsibility and accountability is essential to the economic and fiscal health of our nation.", "My father was a member of the Teamsters Union in California, where he helped to organize better health care for workers. My mother worked for more than 20 years on an assembly line.", "I think a lot of trainers are forgetting to take care of themselves and focusing only on their clients. You see it with doctors, nurses, and caretakers. If you put too much effort into only helping others, you are neglecting yourself, and your health is the only thing that makes it possible for you to help others.", "Happiness, contentment, the health and growth of the soul, depend, as men have proved over and over again, upon some simple issue, some single turning of the soul.", "A Health Affairs study comparing patient-satisfaction scores with HCAHPS surveys of almost 100,000 nurses showed that a better nurse work environment was associated with higher scores on every patient-satisfaction survey question.", "I entered the health care debate in response to a statement in the United States press in summer 2009 which claimed the National Health Service in Great Britain would have killed me off, were I a British citizen. I felt compelled to make a statement to explain the error.", "The car provided Americans with an enviable standard of living. You could not get a steady job with high wages and health and retirement benefits working on the General Livestock Corporation assembly line putting udders on cows.", "I always made my food congenial to my constitution, and my health was always excellent.", "The bottom line is, I'm blessed with good health. On top of that, I don't go around thinking 'Oh, I'm 90, I better do this or I better do that.' I'm just Betty. I'm the same Betty that I've always been. Take it or leave it.", "Yoga is at the core of my health and wellness routine; even if it's only for 10 to 15 minutes I find it helps me to re-center and to focus as well as improve my overall core strength.", "The type of leukemia that I am dealing with is treatable. So if I do what my doctors tell me to do - get my blood checked regularly, take my meds and consult with my doctor and follow any additional instructions he might make - I will be able to maintain my good health and live my life with a minimum of disruptions to my lifestyle.", "You can't have public health without a public health system. We just don't want to be part of a mindless competition for resources. We want to build back capacity in the system.", "Anywhere you have extreme poverty and no national health insurance, no promise of health care regardless of social standing, that's where you see the sharp limitations of market-based health care.", "The only trouble here is they won't let us study enough. They are so afraid we shall break down and you know the reputation of the College is at stake, for the question is, can girls get a college degree without ruining their health?", "You may not know your complete family history, but the reality is everyone has something, and as you get older, you start to worry about these things more. Health is not sort of like a 6-month project. Health is a lifetime accumulation of behaviors.", "We have to see that we're a part of each other, and we have to take care of each other. The reason why they have universal health care in Canada and Britain, these other places? Because they believe if one suffers, everybody suffers.", "Whole Foods has a good health care plan.", "Nature is a numbers game. We need all the support we can get as our immune systems and health are under assault from pollution, stress, contaminated food and age-related diseases as our lifespans increase.", "If we focus on our health, including our inner health, our self-esteem, and how we look at ourselves and our confidence level, we'll tend to be healthier people anyway, we'll tend to make better choices for our lives, for our bodies, we'll always be trying to learn more, and get better as time goes on.", "What good is telling America's children that they will have equal opportunity for education if they don't have the skills that will even get them to the point of benefiting from education, because they didn't have the child care, the health care that would enable them to grow as strong and constructive human beings?", "Well, you know my number one cause has always been that women's reproductive health needs to be protected.", "When you have cancer, it's like you enter a new time zone: the Cancer Zone. Everything in the Tropic of Cancer revolves around your health or your sickness. I didn't want my whole life to revolve around cancer. Life came first; cancer came second.", "In my forties, my optimism was boundless. I had really good health and tremendous success which allowed me to do anything I wanted.", "If Obamacare is allowed to stand - and Congress is allowed to make the purchase of government-endorsed health insurance compulsory - there will be no meaningful limit on Washington's reach into the lives of the American people. That is certainly not what the Founders intended.", "Seeds and nuts are indispensable for cardiovascular health. The protective properties of nuts against coronary heart disease were first recognized in the early 1990s, and a strong body of literature has followed, confirming these original findings.", "I think jogging is bad for your health. All that pressure on the knees and back cannot be good for you.", "If some consumers believe that it's better from the point of view of their health to have organic food, God bless them. Let them buy it. Let them pay a bit more.", "People who don't know how to keep themselves healthy ought to have the decency to get themselves buried, and not waste time about it.", "Charities are now working to give people in poor countries access to the Internet. But shouldn't we spend that money on providing health clinics and safe water? Aren't these things more relevant? I have no intention of downplaying the importance of the Internet, but its impact has been exaggerated.", "Your body hears everything your mind says.", "You go into the book store, there's the cut-out of Dr. Phil, and then the dreaded women's health section where every book, instead of the menopause book with the fanged Medusa head on the cover that might be more pertinent, you always see a flower and a poppy and a daisy and a stethoscope.", "I have long understood that climate change is not only an environmental issue - it is a humanitarian, economic, health, and justice issue as well.", "Around New York City, samples collected at dozens of beaches or piers have detected the types of bacteria and other pollutants tied to sewage overflows. Though the city's drinking water comes from upstate reservoirs, environmentalists say untreated excrement and other waste in the city's waterways pose serious health risks.", "Health is your greatest wealth, so experiencing a marathon and seeing what you're capable of is really special.", "Science and mindfulness complement each other in helping people to eat well and maintain their health and well-being.", "If we can get people to focus on fruits and vegetables and more healthy foods, we'll be better in terms of our healthcare situation.", "New, unfamiliar, and mysterious threats to our health are scary. At the Centers for Disease Control and Prevention - where we identify, on average, one new health threat each year - we work around the clock with an approach that prioritizes finding out what we need to know as fast as we can to protect Americans.", "Effective health care depends on self-care; this fact is currently heralded as if it were a discovery.", "A comfortable house is a great source of happiness. It ranks immediately after health and a good conscience.", "The only way you multiply resources is with technology. To really affect poverty, energy, health, education, or anything else - there is no other way.", "Nothing is more capable of troubling our reason, and consuming our health, than secret notions of jealousy in solitude.", "I believe our health care system is in drastic need of innovative, patient-centered reforms that encourage competition and increase consumer choice, not the bloated bureaucracy, tax increases, rationing, and mandates in the president's government takeover.", "If you look at things that really affect people's lives - sport, the arts, charities - they were always at the back of the queue for government money - health, social security, defence, pensions were all way ahead. And each of those areas - sports, the arts, the lottery - got relatively petty cash from the government.", "Increase your consumption of healthful fats like extra virgin olive oil, avocado, grass-fed beef, wild fish, coconut oil, nuts and seeds. At the same time, keep in mind that modified fats like hydrogenated or trans fats are the worst choices for brain health.", "People shouldn't look at me and think life is one big piece of glamour. That's the marketing, the spin. Life is challenging. But I have courage, strength, and enough good health to see the positive.", "I've never followed a vegan or vegetarian diet in the past, but I think I could do it. It would not be easy. I have worked with nutritionists who have said a vegan diet is not necessarily all positive for your health, because you need nutrients you only find in meats. I believe in a balanced diet.", "It's okay to talk about birth, okay - then menstruation. I first started my advocacy for women's health in the field of reproductive freedom, and the next stage would be bringing menopause out of the closet.", "I'm grateful for my health, glad I'm making people laugh, glad my wife still likes me after a lotta years, grateful my daughter is growing, glad I don't take myself too seriously, glad L.A. has Astro Burger, grateful to be coming home to Harlem soon. It's a gratitude list. It works.", "Experience taught me that working families are often just one pay check away from economic disaster. And it showed me first-hand the importance of every family having access to good health care.", "We have really good data that show when you take patients and you really inform them about their choices, patients make more frugal choices. They pick more efficient choices than the health care system does.", "I think health care is more about love than about most other things. If there isn't at the core of this two human beings who have agreed to be in a relationship where one is trying to help relieve the suffering of another, which is love, you can't get to the right answer here.", "I don't believe we ought to discriminate against people because of their sexual orientation. If people are in a same-sex relationship, and they want their partner to be able to have health benefits or be designated as a beneficiary in your life insurance, there's no reason we shouldn't do that.", "Life is a perspective and for me, if a human being has access to school, clean water, food, proper health care, that is the basis of human rights.", "I'm interested in women's health because I'm a woman. I'd be a darn fool not to be on my own side.", "I have never felt more confident in myself, more clear on who I am as a woman. But I am constantly thinking about my own health and making sure that I'm eating right and getting exercise and watching the aches and pains. I want to be this really fly 80-90-year old.", "The greatest of follies is to sacrifice health for any other kind of happiness.", "I purposely don't talk about money, because people are already skeptical about TV preachers. But I do say that I want you to be blessed. To me, prosperity is having health, having great children, having peace, good relationships. It's not about the money.", "In societies where mature workers are respected and where their wisdom is respected, everybody benefits. Workers are more engaged and productive. Their health is better. They live longer.", "It is better to lose health like a spendthrift than to waste it like a miser.", "Talk is by far the most accessible of pleasures. It costs nothing in money, it is all profit, it completes our education, founds and fosters our friendships, and can be enjoyed at any age and in almost any state of health.", "The Blunt Amendment would have allowed any employer who provided health insurance, or any insurance company, the right to deny coverage for contraception or any other kind of procedure if the employer had a 'moral' objection to it.", "When I talk about democratic socialist, I am talking about Medicare, a single payer health care system for the elderly. And in my view, we should expand that concept to all people. I believe that everybody in this country should be entitled to health care as a right.", "The seven deadly sins: Want of money, bad health, bad temper, chastity, family ties, knowing that you know things, and believing in the Christian religion.", "A considerable share of the world's population still cannot afford comfortable housing, education and quality health care.", "A woman's health is her capital.", "Health care historically has been a very siloed field that's organized around medical specialties - urology, cardiac surgery, and so forth - and around the supply of these specialty services. The patient is the ping-pong ball that moves from service to service.", "Parks represent an efficient, cost-effective way to improve public health.", "With happiness as with health: to enjoy it, one should be deprived of it occasionally.", "Eating ice cream and not exercising is great. The downside is your health isn't so good.", "Our Congress passes laws which subsidize corporation farms, oil companies, airlines, and houses for suburbia. But when they turn their attention to the poor, they suddenly become concerned about balancing the budget and cut back on the funds for Head Start, Medicare, and mental health appropriations.", "Obamacare is not about improved health care or cheaper insurance or better treatment or insuring the uninsured, and it never has been about that. It's about statism. It's about expanding the government. It's about control over the population. It is about everything but health care.", "If you're healthy, if you don't get sick much, if you don't go to the doctor much or use your health insurance much, you are a genetic lottery winner. It has nothing to do with the way you live, nothing to do with doing the right things. It's just sheer luck, and you are gonna pay for that.", "Cycling is good for people in all ways: their health, their well-being, and it does no damage to the environment. It can, however, be dangerous, and this has to be addressed.", "We cannot continue. Our pension costs and health care costs for our employees are going to bankrupt this city.", "Priesthood quorums teach and assist their members to attain good health, financial stability, and a year's supply of food and clothing. They also teach their members to be self-reliant and to give their time, talents, and means in behalf of the Church, community, and needy.", "Nobody wins when the police are sent to look after people suffering from mental health problems; vulnerable people don't get the care they need and deserve, and the police can't get on with the job they are trained to do.", "One thing governors feel, Democrats and Republicans alike, is that we have a health care system that, if you're on Medicaid, you have unlimited access to health care, at unlimited levels, at no cost. No wonder it's running away.", "Success is measured in months for me. When my health fails, it will fail quickly. Tumors grow on an exponential curve.", "The filth and noise of the crowded streets soon destroy the elasticity of health which belongs to the country boy.", "Money is to my social existence what health is to my body.", "Of all mushrooms commonly consumed, oyster mushrooms in the genus Pleurotus stand out as exceptional allies for improving human and environmental health. These mushrooms enjoy a terrific reputation as the easiest to cultivate, richly nutritious and medicinally supportive.", "I believe in taxation and health care that is outside the usual libertarian mandate, because I don't want people to have to suffer. It's as simple as that.", "I have profoundly mixed feelings about the Affordable Care Act. What I love about it is its impulse. It attempts to deal with this intractable problem in American health care life, which is that a significant portion of the population does not have access to quality medical care.", "I loved growing up in Canada. It's a great place to grow up because - well, at least where I grew up - it's very multicultural. There's also good health care and a good education system.", "The arts have always been an important ingredient to the health of a nation, but we haven't gotten there yet.", "Legally speaking, the term 'public rights' is as vague and indefinite as are the terms 'public health,' 'public good,' 'public welfare,' and the like. It has no legal meaning, except when used to describe the separate, private, individual rights of a greater or less number of individuals.", "Taking care of your mental and physical health is just as important as any career move or responsibility.", "Providing health care is like building a house. The task requires experts, expensive equipment and materials, and a huge amount of coordination.", "To successfully lose weight after 40, you need to understand that imbalanced hormones and chemicals have a huge impact on your health. It is possible, however, to live a clean, healthy, and long life - with a slim body, even after 40!", "I basically believe the medical insurance industry should be nonprofit, not profit-making. There is no way a health reform plan will work when it is implemented by an industry that seeks to return money to shareholders instead of using that money to provide health care.", "We know a great deal more about the causes of physical disease than we do about the causes of physical health.", "No innovation in the past 200 years has done more to save lives and improve health than the sanitation revolution triggered by invention of the toilet. But it did not go far enough. It only reached one-third of the world.", "I do not want medical men to discuss whether or not my work is valuable, because I know what it will do. I want them to tell me how best this new knowledge of rapidly restoring paralysed people to health and strength can be applied where it is needed.", "Well, we lost a lot of our independence already. We are dependent on China for credit. We are dependent on Middle Eastern countries for energy supplies. And many Americans are dependent on the government for their income, health care, education of their children, food stamps.", "The best advice is to avoid foods with health claims on the label, or better yet avoid foods with labels in the first place.", "I don't remember 'Doctor Who' not being part of my life, and it became a part of growing up, along with The Beatles, National Health spectacles, and fog. And it runs deep. It's in my DNA.", "I think it's time to have a celebration of life and renew our vows. And this time we're going to write the vows because they're going to mean a lot more. We certainly put the 'in sickness and in health' vow to the test the last year and half.", "I should do something about the cigarettes; I quite accept that it's bad for your health, but you know a moderate tipple is positively beneficial and, at certain times, absolutely essential.", "The World Health Organization has recognized acupuncture as effective in treating mild to moderate depression.", "We must work together to strengthen Jerusalem as a modern, open capital and to foster welcoming, inclusive communities across the Jewish world. It is vital to the health and vibrancy of the global Jewish future and to ensuring a strong Israel.", "Our children's health and well-being are dependent on our commitment to promoting food access and good eating habits at home, at school and in the community.", "I travel the world visiting global health programs as an ambassador for the global health organization, PSI, and sometimes the disconnect I see is truly striking: people can get cold Coca Cola, but far too infrequently malaria drugs; most own mobile phones, but don't have equal access to pre-natal care.", "One of the things I like best about 'Biggest Loser' is being around people who are trying to make the right choices. When you feel defeated about your weight and your health, like there's no hope, and you still make the choice to fight for it, to make the change happen no matter what people say or think, that's inspiring to me.", "Hey 'Bachelor,' take notes! Trusting one another and sharing a journey to health leads to lasting relationships!", "People who are always taking care of their health are like misers, who are hoarding a treasure which they have never spirit enough to enjoy.", "State and local law enforcement are the primary protectors of the health, safety, and welfare of the people in the individual states.", "Even if you walk exactly the same route each time - as with a sonnet - the events along the route cannot be imagined to be the same from day to day, as the poet's health, sight, his anticipations, moods, fears, thoughts cannot be the same.", "Your own personal health is your own personal choice, all the way down the line.", "And whether it is equal pay, health care, Social Security, or family leave, this Congress has refused to address issues critical to hard-working American women.", "Half of all women who are sexually active, but do not want to get pregnant, need publicly funded services to help them access public health programs like Medicaid and Title X, the national family planning program.", "Do we talk about the dignity of work? Do we give our students any reason for believing it is worthwhile to sacrifice for their work because such sacrifices improve the psychological and mental health of the person who makes them?", "We should work to guarantee that there is a midwife or health worker by every woman's side during childbirth.", "One of the jewels in the crown of Labour's time in office was the rescue of the National Health Service. As the Commonwealth Fund, the London School of Economics and the Nuffield Foundation have all shown, health reforms as well as additional investment were essential to improved outcomes, especially for poorer patients.", "Two forms of fat that are vitally important for brain health are cholesterol and saturated fat.", "You end up as you deserve. In old age you must put up with the face, the friends, the health, and the children you have earned.", "I have the ability and to have access to and to learn more in different areas in wellness and health because I have the door open to me to any doctor, any scientist, any hospital, any study around the world. I believe it's my responsibility to share that information with others.", "'Everything To Me' is about everything that's important. It's about my wife, my kids, it's about life, about being happy. It's about life in general, you know, about not knowing what's going to be around the corner, but you've got to enjoy it and enjoy the things you have. My wife, my kids, my health, and stuff like that.", "You have to fight for your health and stay on top of it. Our bodies are meant to be healthy.", "Global health issues remind us - perhaps more than any other issue - that we are all children of the same extended family.", "Everyone should have health insurance? I say everyone should have health care. I'm not selling insurance.", "I think we do better as a country when we go step by step toward a goal, and the goal in this case should be reducing health care costs.", "My hobbies include maintaining my physical and mental health. It's a full-time job. Yoga definitely helps for both of them. I'm a big fan of relaxing and not having a schedule. That's my best way to keep from going crazy.", "Remember our proud history of social justice, universal health care, public pensions and making sure no one is left behind. Let's continue to move forward.", "There is a new wave of environmental consumers I like to call Pocketbook Environmentalists. They're going green primarily because it makes good financial sense, but the fact that it benefits their families' health and the environment also makes them feel good.", "I sit on my duff, smoke cigarettes and watch TV. I'm not exactly a poster girl for healthy living.", "Buildings designed with careful attention to aesthetics arouse and enlighten their occupants and that promotes their good health.", "I eat really healthy, and if I'm tired, I take a nap.", "Nurses serve their patients in the most important capacities. We know that they serve as our first lines of communication when something goes wrong or when we are concerned about health.", "As problems like identity theft become more prevalent, now more than ever, Americans need to take their financial health seriously - and this information is of the utmost importance.", "Illegal immigrants are beginning to comprise a black market class of workers in our society, jeopardizing the financial health of companies which play by the rules, while themselves vulnerable to the exploitation by those willing to take advantage of their illegal status.", "The difference between rich and poor is becoming more extreme, and as income inequality widens the wealth gap in major nations, education, health and social mobility are all threatened.", "No one has the right to threaten the health, education, and well-being of children by involving them in illegal or inappropriate work.", "I'm a big believer in what's called personalized medicine, which refers to customizing your health care to your specific needs based on your physiology, genetics, value system and unique conditions.", "The importance of heart health became very real for me when my father died of heart disease seven years ago. Having experienced the loss first hand, I am inspired to do everything I can to break the cycle and prevent families from losing loved ones to this preventable disease.", "When I wrote 'Silver Linings,' I thought I was writing a book about the Philadelphia Eagles and male bonding, but when the book came out, it was surprising to me that the mental health community embraced it.", "Illegal immigration is a genuinely national issue, and resolving it requires a national commitment not just on health care but also border control, law enforcement and other resources.", "President Obama is also standing up for women in North Carolina and across our country. He has helped women fight for equal pay for equal work; he has fought to guarantee that women have access to quality, affordable health care, including making sure that insurance plans cover birth control with no out-of-pocket cost.", "Everything we've been taught about health, weight loss and aging is wrong.", "Average Americans are going to win this, not me. And not just your organization, not just the providers of health care, but the American people are going to cause this to happen. But they have to keep sending those cards and letters.", "Demography is changing us as we are older societies, we're living longer. How the generations balance each other out, how that affects education and health care.", "Medicines are unusual commodities. Important drugs can save the lives and protect the health of millions. Their consumption can bring huge benefits, by helping patients to avoid infection and preventing serious damage to the economies of families, nations and even humanity at large.", "As obesity creeps into preschools, and hypertension and type II diabetes become pediatric problems for the very first time, the case for starting preventive health care in the cradle has become too compelling to keep ignoring.", "Unfortunately, we force people to break the law in order to get any kind of mental health treatment.", "I know that there are millions of Americans who are content with their health care coverage - they like their plan and, most importantly, they value their relationship with their doctor.", "Contrary to popular belief, I don't spend a whole lot of time following soccer. But as I have traveled around the world to better understand global development and health, I've learned that soccer is truly universal. No matter where I go, that's what kids are playing. That's what people are talking about.", "In a disordered mind, as in a disordered body, soundness of health is impossible.", "Use your health, even to the point of wearing it out. That is what it is for. Spend all you have before you die; do not outlive yourself.", "When it comes to the health of our families, Barack refused to listen to all those folks who told him to leave health reform for another day, another president. He didn't care whether it was the easy thing to do politically - that's not how he was raised - he cared that it was the right thing to do.", "If workers are more insecure, that's very 'healthy' for the society, because if workers are insecure, they won't ask for wages, they won't go on strike, they won't call for benefits; they'll serve the masters gladly and passively. And that's optimal for corporations' economic health.", "I've had extraordinary good luck with my health, other than a broken elbow.", "Overnight stardom can be harmful to your mental health. Yeah. It has ruined a lot of people.", "The trouble with always trying to preserve the health of the body is that it is so difficult to do without destroying the health of the mind.", "I have always detested any departure from reality, an attitude which I relate to my mother's poor mental health.", "There is a wisdom in this beyond the rules of physic: a man's own observation what he finds good of and what he finds hurt of is the best physic to preserve health.", "Health consists with temperance alone.", "Fame and power are the objects of all men. Even their partial fruition is gained by very few; and that, too, at the expense of social pleasure, health, conscience, life.", "If the goal of health-care reform is to provide comprehensive, universal health care in a cost-effective way, the only honest approach is a single-payer approach.", "These are the same people who believe, in some cases, the federal government should not play any role in providing health care to our people or protecting the environment.", "2013 was a year of myths falling apart. The myth of President Obama - a myth in which Obama was a messianic figure descending to bequeath health care, equality, and brotherhood on mankind - imploded. The myth of an America embracing the leftist social agenda collapsed.", "I just want to be healthy and stay alive and keep my family going and everything and keep my friends going and try to do something so that this world will be peaceful. That is the most ambitious and the most difficult thing, but I'm there trying to do it.", "The body is a sacred garment.", "I think all Americans believe in human rights. And health is an often overlooked aspect of basic human rights. And it's one that's easily corrected. The reason I say that is that many of the diseases that we treat around the world, I knew when I was a child. My mother was a registered nurse. And they no longer exist in our country.", "We are all representatives of the American people. We all do town hall meetings. We all talk to our constituents. And I've got to tell you, the American people are engaged. And if you think they want a government takeover of health care, I would respectfully submit you're not listening to them.", "Many companies today are reducing hours of full-time people to get under the minimum so they don't have to pay health care costs. I just shake my head because that's not going to build long-term value and trust with your people.", "Sobriety and health is the greatest thing.", "I have never written that there is a threat of fascism in America. I always considered the idea overwrought. But now I believe there really is such a threat - and it will come draped not in an American flag, but in the name of tolerance and health.", "The fear of health care changing is beyond belief. Like there's a way to make the system worse. Really?", "Nothing is more valuable to people than health care, and by paying, they feel less like beggars and more like 'customers' who can and should demand quality care.", "There is a self interest in voting for a society where there is health care for all, where there's a mental health service for all, where there is education service for all.", "I am upset and completely disappointed in the government, the millionaires and billionaires in the U.S. See what's happening to the country? Look at all the health problems, the economy, the recession and crime.", "I neglected my health, and I was reluctant to have medical check-ups. It was a fundamental mistake for a revolutionary, to the Venezuelan people and the international public opinion.", "Did you know that nearly one in three children live apart from their biological dads? Those kids are two to three times more likely to grow up in poverty, to suffer in school, and to have health and behavioral problems.", "There are less than 1 per cent of anorexic girls, but there more than 30 per cent of girls in France - I don't know about England - that are much, much overweight. And it is much more dangerous and very bad for the health.", "If any country was a mine-shaft canary for the reintroduction of cholera, it was Haiti - and we knew it. And in retrospect, more should have been done to prepare for cholera... which can spread like wildfire in Haiti... This was a big rebuke to all of us working in public health and health care in Haiti.", "As a physician specializing in nutrition, my priority is to the health of the public.", "It's about businesses nervous about taking on school leavers because of a mass of red tape. It's about health and safety regulations and green fines.", "In health there is freedom. Health is the first of all liberties.", "You bet every member of Congress who votes for this bill ought to read it, read it thoroughly, and understand that what we're looking at here amounts to nothing more than a government takeover of our health care economy, paid for with nearly a trillion dollars in new taxes on individuals and small businesses. And it must be opposed.", "I pray every day, several times. It soothes me. I don't ask for anything, except for health.", "The fact that my environment influences my life so much - and that my environment is in my control - gives me a great sense of empowerment over my health and my life.", "Disasters such as earthquakes, tsunamis, volcanoes, floods, oil spills and radioactive fallout cause massive death of people, pigs, bats and birds. These disasters also impact the immune health of survivors. All harbor viruses.", "America was not founded to improve health care or housing; it was founded for freedom.", "When I go to my health club, and it's in the basement, you have to take the elevator down. And this drives me crazy. Why can't there be a stairway? At least make it as easy to exercise as it is to not exercise. It's in society's interest for me to take the stairs.", "I am actually one of those who took President Obama at his word when he first ran - that he would get us out of ill-advised wars, that he would do something about health care costs, and that he would protect civil liberties. Like many Americans, I was disappointed.", "I think police officers can work with social workers and public health nurses to do so much in terms of addressing the problem of American families, of children in American families as a whole, and giving them an opportunity to get off to a fresh start, to become self-sufficient, to lead safe, constructive lives.", "I find it a lot healthier for me to be someplace where I can go outside in my bare feet.", "As a doctor, when I was minister of health and would go somewhere, little girls would come up to me and say, 'I want to be like you one day, I want to be a doctor.' Now, they tell me, 'I want to be president just like you.' All of us can dream as big as we want.", "The only principles of public conduct that are worthy of a gentleman or a man are to sacrifice estate, ease, health, and applause, and even life, to the sacred calls of his country.", "It's funny, I do try to maintain health. I started doing Bikram yoga which is that hothouse yoga, the 105 degrees yoga for 90 minutes. It's great, you purge out all the sweat and you're drinking water.", "Every evil is a sickness of soul, but virtue offers the cause of its health.", "All know the importance of sustaining the hopes of a sick man. The reason of this is that his nervous system is then, vastly more than in health, susceptible to the influence of particular states of the mind.", "We drink one another's health and spoil our own.", "Every health expert tells you to eat breakfast. I had the mentality, 'I'll save those calories!' But then you are starving, and you overeat.", "The next frontier in nutrition will be about reconfiguring diets according to individual specific physiology, lifestyle, and health goals.", "Health and wellness does mean different things to different people.", "Health food may be good for the conscience but Oreos taste a hell of a lot better.", "I hope someday we will be able to proclaim that we have banished hunger in the United States, and that we've been able to bring nutrition and health to the whole world.", "Once you digitize data, you can actually analyze patterns and relationships in geographic space - relationships between certain health patterns and air or water pollution, between plants and climate, soils, landscape.", "I think that going on any reality show is not good for your mental health because you behave differently when you are being watched, and you constantly have an extra bit of awareness of what's going on all the time.", "Today we have a health insurance industry where the first and foremost goal is to maximize profits for shareholders and CEOs, not to cover patients who have fallen ill or to compensate doctors and hospitals for their services. It is an industry that is increasingly concentrated and where Americans are paying more to receive less.", "Rogue internet pharmacies continue to pose a serious threat to the health and safety of Americans. Simply put, a few unethical physicians and pharmacists have become drug suppliers to a nation.", "The voice collects and translates your bad physical health, your emotional worries, your personal troubles.", "Clearly, Mayor Bloomberg did some things right. I think he did a very good job on public health. He did a very good job on environment. I think he was right to achieve mayoral control of education. I don't think he then applied it the right way.", "If our hearts are ready for anything, we can open to our inevitable losses, and to the depths of our sorrow. We can grieve our lost loves, our lost youth, our lost health, our lost capacities. This is part of our humanness, part of the expression of our love for life.", "It's no longer a question of staying healthy. It's a question of finding a sickness you like.", "We readily go to the health club when our doctor suggests we need more exercise, but we regularly neglect the 'mental health club' that our well-being more truly requires.", "Drinking water that does not meet a federal health guideline will not necessarily make someone ill. Many contaminants are hazardous only if consumed for years. And some researchers argue that even toxic chemicals, when consumed at extremely low doses over long periods, pose few risks.", "I believe that both people in a marriage should be concentrated on health, and you should be inspiring each other. How to make your mind healthier, how to make your body healthier. Healthy mind, healthy body, healthy soul.", "Productive achievement is a consequence and an expression of health and self-esteem, not its cause.", "Going vegetarian - and then vegan - has calmed me down, and it has also made me physically and emotionally strong. I do crave meat once in a while, but I find that spiritually, non-vegetarian food works against my emotional health.", "Teaching kids about health and fitness is important to me. It's about being fit for life.", "Soaring prescription drug costs have placed a tremendous strain on family budgets. They have also imposed a heavy burden on employers - both public and private - who are struggling to provide affordable health insurance coverage to their workers.", "If our goal is to provide health care to our veterans, why does it need to be in the bricks and mortar of bureaucracy of the VA? Why can't you give them an insurance card and let them go to a health care provider of their choice?", "Gun owners and non-gun owners alike agree on expanding background checks, making gun trafficking a serious crime with stiff penalties, making it illegal for all stalkers and all domestic abusers to buy guns, and expanding mental health resources so the mentally ill find it easier to receive treatment than to buy firearms.", "With longer life spans and better health and education, many feel that giving birth to a baby a mere couple of decades after they themselves were in the cradle is a little premature.", "Our government has failed us. From the billion-dollar bailouts to the 'stimulus' package that failed to stimulate to the government takeover of health care, you cried 'Stop!'... but the Democratic Majority in Washington has refused to listen.", "The biggest mistake people make is to try to lose too much weight too fast.", "You get the health benefits of coffee up through about the first twenty-four ounces. It's the biggest source of antioxidants for Americans, and we think it helps prevent Alzheimer's and Parkinson's as well.", "If we can make the correct diagnosis, the healing can begin. If we can't, both our personal health and our economy are doomed.", "We need to accept the seemingly obvious fact that a toxic environment can make people sick and that no amount of medical intervention can protect us. The health care community must become a powerful political lobby for environmental policy and legislation.", "Whenever I write about mental health and integrative therapies, I am accused of being prejudiced against pharmaceuticals. So let me be clear - integrative medicine is the judicious application of both conventional and evidence-based natural therapies.", "The bottom line is that the human body is complex and subtle, and oversimplifying - as common sense sometimes impels us to do - can be hazardous to your health.", "Health care is not a privilege. It's a right. It's a right as fundamental as civil rights. It's a right as fundamental as giving every child a chance to get a public education.", "If we're going to be able to provide access to quality, affordable health care to every American - we need to have the trained health care professionals inside hospitals to provide that care.", "Diets don't come into it. You need variety and to have a good source of greens, protein, and nutrition. It is about health rather than looking right.", "It was challenging. It was never easy for me. My life changed suddenly, and I lost my health. I lost the body that I knew.", "When you start fooling around with drugs, you're hurting your creativity, you're hurting your health. Drugs are death, in one form or another. If they don't kill you, they kill your soul. And if your soul's dead, you've got nothing to offer, anyway.", "America is the one rich country with the biggest slums, the least democratic and least developed health system, and the most niggardly attitude against its old people.", "India remains one of the few nations which still focuses entirely on an archaic de-addiction model, administered by the ministry of social justice and empowerment, to address drinking problems, adhering to a centuries-old idea of these problems being a moral disorder rather than a health condition.", "Children have to be provided a nurturing environment to grow. Sadly, in India we don't have a robust mental health programme for children. There is also a lack of accountability in the public system.", "Government is, by its very nature, a destroyer of liberties; the Obama administration, specifically, is promising to interfere with the economy and the health care system so profoundly that Washington will soon have us all in chains.", "Mark Ruffalo, aka the Incredible Hulk, is the natural gas industry's worst nightmare: a serious, committed activist who is determined to use his star power as a superhero in the hottest movie of the moment to draw attention the environmental and public health risks of fracking.", "Hot, dry katabatic winds, like the south foehn in Europe, the sharav in the Middle East, and the Santa Ana of Southern California, are all believed to have a decided effect on human behavior and are associated with such health problems as migraines, depression, lethargy, and moodiness. Some scientists say that this is a myth.", "A moderate addiction to money may not always be hurtful; but when taken in excess it is nearly always bad for the health.", "A teacher must believe in the value and interest of his subject as a doctor believes in health.", "Men need to be aware of the health of their bodies, as well - prostate cancer and breast cancer are almost on the same level. It's fascinating to me that the correlation between the two is almost the same - people don't talk about it so much, but they are almost equal in numbers.", "The fierce battles between New Democrat centrists and old-style liberals that defined the Democratic Party in the 1990s are long gone, with the party unified behind Barack Obama's economic agenda of universal health care, expensive federal programs and more regulation of the financial markets.", "Research shows that when women are empowered as political leaders, countries often experience higher standards of living with positive developments in education, infrastructure, and health care.", "Health care is a design problem. Dependence on foreign oil is a design problem. To some extent, poverty is a design problem. We need design thinkers to solve those problems, and most people who are in positions of political power are not design thinkers, to put it mildly.", "Real Texans don't want any woman to die of cancer because she can't get decent health care or medical advice. Real Texans don't want any woman to lose control of her life because she can't get birth control.", "The true index of a man's character is the health of his wife.", "Money spent on carbon cuts is money we can't use for effective investments in food aid, micronutrients, HIV/AIDS prevention, health and education infrastructure, and clean water and sanitation.", "People are going to be living quite soon for 100 years. Our idea of how a family works no longer applies. It's no good saying you're going to have children for 15 years and then you're going to retire and have hobbies, because you've got 40 more years to go after 60 and you're in good health until 90 or something.", "We're so marinated in the culture of speed that we almost fail to notice the toll it takes on every aspect of our lives - on our health, our diet, our work, our relationships, the environment and our community.", "For the past two years, President Obama has promised our children the moon, stars, rainbows, unicorns and universal health care for all. But the White House Santa's cradle-to-grave entitlement mandates are a spectacularly predictable bust.", "I believe health care is a civil right.", "I lived in a town of 400 until I was like nine or ten. My dad coached all the sports - he was a gym teacher and health teacher for grades K-12.", "We ought to follow through on an idea that was first proposed by President Clinton to allow people over the age of 55 who are not eligible for Medicare into the Medicare system, at cost, and below cost for those who can't afford it. That takes care of a significant number of the people who don't have health insurance.", "In mid-May, the House of Representatives approved the full amount of money that the Veterans Administration said was needed for next year - plus an additional $1 billion increase for veterans' health care.", "We must take action now, by permitting re-importation, to ensure that health care and prescription drugs remain accessible and affordable for everyone.", "One in seven Americans lives without health insurance, and that's a truly staggering figure.", "The cognitive skills prized by the American educational establishment and measured by achievement tests are only part of what is required for success in life. Character skills are equally important determinants of wages, education, health and many other significant aspects of flourishing lives.", "When I left my parents' home when I was 19, I went to the University of Florida, and within 24 hours was in the mental health department. And within 20 minutes, I was being told by the director there that they didn't have what I needed there.", "America's veterans deserve the very best health care because they've earned it.", "When the courts decide that murderers, rapists, and others who maliciously break our social contract deserve health care that most working Americans can't afford, they are condemning good people to death.", "If we can provide even a few months of early warning for just one pandemic, the benefits will outweigh all the time and energy we're devoting. Imagine preventing health crises, not just responding to them.", "There are lots of people with mental health disabilities, and that's just the way their life is; it's not like you see it in the movies.", "Most illegals are without health insurance, and when these workers need emergency healthcare, the American taxpayer gets stuck with the bill.", "Measles is probably the best argument for why there needs to be global health, and why we have to think about it as a global public good. Because in a sense, measles is the canary in the coal mine for immunization. It is, you know, highly transmissible. The vaccine costs 15 cents, so it's not - you know, shouldn't be an issue in terms of cost.", "Thankfully, President Obama has stood firmly behind women's health care issues by supporting coverage for contraception and reaffirming commitment to organizations like Planned Parenthood.", "Our cultural discussion of fat bodies and how we clothe them has nothing to do with health concerns, the obesity epidemic, or the comfort of fat people. It has everything to do with what we expect from women, what we've been told by the fashion industry, and the value we place on 'perfect' bodies.", "Security is still the most important issue facing Washington state residents and millions of Americans - the security of having a job, of access to affordable health care, of a quality education, and of protecting our homeland and defending our nation.", "I became a vegetarian out of compassion for animals and to live as healthy as possible. I realized soon after that I was truly concerned with nonviolent consumption and my own health, a vegan diet was the best decision.", "Newborn screening is a public health intervention that involves a simple blood test used to identify many life-threatening genetic illnesses before any symptoms begin.", "To maximize our potential to enhance our health and our knowledge, we should remain open to new understanding and evolving technology or resources that might inspire a change in our approach to these important questions.", "When I'm engaged in a story my health is not a big deal, but when I'm not doing anything, if you sit me down, I can get tied up in my own medical dramas. So I much prefer to work.", "In capital we trust. Capital is our savior, our holy grail, our fountain of youth, or at least health, for banks.", "I believe in the vows that I took with my wife. Through sickness, in health, for richer or poorer.", "It's important for moms, but also dads, to recognize that they're role models when it comes to their kids' physical health, when it comes to working out, and when it comes to nutrition.", "Whatever concerns health is of real public interest.", "I love working out. It's my release. I've done it since I've been in the military.", "The Internet was appealing partly because it was something I could do in bed and feel like I was achieving something. I had an operation when I was 13 and ended up with complications, so I was in and out of the hospital. The bottom line is you can get through health challenges. It's part of why I was so driven.", "Health and beauty is not just about what you apply. If you don't have it together on the inside, then nothing else is going to matter.", "I have seen that technology has contributed to improved communication, that it's contributed to better health care, that it's contributed to better food supplies, that it has contributed to all the basic human needs.", "I learned that people everywhere are basically the same and have similar goals that we do. They want health and happiness and the opportunity to provide for their families.", "I'm convinced that we can shape a different future for this country as it relates to mental health and as it relates to suicide.", "For he who has health has hope; and he who has hope, has everything.", "The same things that lead to disparities in health in this country on a day-to-day basis led to disparities in the impact of Hurricane Katrina.", "Cheerfulness, sir, is the principle ingredient in the composition of health.", "My good health, coupled with joy of tobogganing and my desire to be the best, has helped me stay in professional sport for so long.", "First of all, pharmaceutical costs are the single fastest-growing part of our health care budget.", "As many citizens can attest, the U.S. is a great place to get sick, but a terrible place to stay well. This requires a shift in the way both doctors and patients approach health maintenance and disease prevention.", "And that means that no matter how we reform health care, we will keep this promise to the American people: If you like your doctor, you will be able to keep your doctor, period. If you like your health care plan, you'll be able to keep your health care plan, period. No one will take it away, no matter what."
        );
        $quote = $this->array_random( $quotes);
		
		$quotedata = get_option('fc_quotedata');
		$quote_status = $quote_position = '';
		if(!empty($quotedata['quote_status'])){
			$quote_status = $quotedata['quote_status'];
		}  
		if(!empty($quotedata['fc_position'])){
			$quote_position = $quotedata['fc_position'];
		} 
		
		if($quote_status == 'on'){
			echo '<div class="fc-quote-wrap '.esc_attr($quote_position).'">'. esc_html($quote) .'</div>';
		}
		else{
			echo '<div class="fc-quote-wrap">'. esc_html($quote) .'</div>';
		}
	}
	public function array_random($arr, $num = 1) {
		shuffle($arr);
		
		$r = array();
		for ($i = 0; $i < $num; $i++) {
			$r[] = $arr[$i];
		}
		return $num == 1 ? $r[0] : $r;
	}
	public function fc_bmi_calculation(){
		$age = $gen = $h_feet = $h_inch = $weight = '';
		if(!empty($_POST['age'])){
			$age = $_POST['age'];
		}
		if(!empty($_POST['gen'])){
			$gen = $_POST['gen'];
		}
		if(!empty($_POST['h_feet'])){
			$h_feet = $_POST['h_feet'];
		}
		if(!empty($_POST['h_inch'])){
			$h_inch = $_POST['h_inch'];
		}
		if(!empty($_POST['weight'])){
			$weight = $_POST['weight'];
		}

		// calculate BMI
		$heightinch = $h_feet * '12';
		$totalheight = $heightinch + $h_inch;
		$heightcm = $totalheight * ('2.54');
		$bmi = ( $weight / $heightcm / $heightcm ) * 10000;
		$fbmi = round($bmi, 1);

		// Calculate BFP
		if($gen == 'male'){
			$bfp = (1.20 * $bmi) + (0.23 * $age) - 16.2; 
		}
		else{
			$bfp = (1.20 * $bmi) + (0.23 * $age) - 5.4;
		}
		$fbfp = round($bfp, 0);

		// Calculate Ideal Weight
		if($age >= 1 && $age <= 5){
			$iweight = 2 * ($age + 5);
		}
		elseif($age > 5 && $age <= 14){
			$iweight = 4 * $age;
		}
		else{
			// if($gen == 'male'){
				// $iweight = 50 + (0.91 * ( $heightcm - 152.4) );
			// }
			// else{
				// $iweight = 45.5 + (0.91 * ( $heightcm - 152.4) );
			// }
			
			$heighm = $heightcm / 100;
			if($gen == 'male'){
				$iweight = 22 * ($heighm*$heighm);
			}
			else{
			    $heighm_wo = ($heightcm - 10)/100;
				$iweight = 22 * ($heighm_wo*$heighm_wo);
			}
		}
		$fiweight = round($iweight, 0);
		
		// Calculate BMR
		if($gen == 'male'){
			$bmr = ( 13.397 * $weight ) + ( 4.799 * $heightcm ) - ( 5.677 * $age ) + 88.362;
		}
		else{
			$bmr = ( 9.247 * $weight ) + ( 3.098 * $heightcm ) - ( 4.330 * $age ) + 447.593;
		}
		$fbmr = round($bmr, 0);
		
		$data = array('status'=>'success','bmi'=>$fbmi,'bfp'=>$fbfp,'idealweight'=>$fiweight,'bmr'=>$fbmr); 
		echo json_encode($data);
		wp_die();
	}
	public function fc_water_intake(){
		$age = $gen = $h_feet = $h_inch = $weight = $season = $activity = '';
		if(!empty($_POST['age'])){
			$age = $_POST['age'];
		}
		if(!empty($_POST['gen'])){
			$gen = $_POST['gen'];
		}
		if(!empty($_POST['h_feet'])){
			$h_feet = $_POST['h_feet'];
		}
		if(!empty($_POST['h_inch'])){
			$h_inch = $_POST['h_inch'];
		}
		if(!empty($_POST['weight'])){
			$weight = $_POST['weight'];
		}
		if(!empty($_POST['season'])){
			$season = $_POST['season'];
		}
		if(!empty($_POST['activity'])){
			$activity = $_POST['activity'];
		}

		// calculate BMI
		$heightinch = $h_feet * '12';
		$totalheight = $heightinch + $h_inch;
		$heightcm = $totalheight * ('2.54');
		$bmi = ( $weight / $heightcm / $heightcm ) * 10000;
		$fbmi = round($bmi, 0);

		if($fbmi < 25 ){
			if($gen == 'male'){
				switch ($age) {
					case "14-18":
						switch($season){
							case "winter":
								$wrp = 3300 * 10 / 100;    // Water Require Percent
								$water_require = 3300 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 3300 * 0;    // Water Require Percent
								$water_require = 3300 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 3300 * 0;     // Water Require Percent
								$water_require = 3300 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "19-30":
						switch($season){
							case "winter":
								$wrp = 3700 * 10 / 100;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 3700 * 0;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 3700 * 0;     // Water Require Percent
								$water_require = 3700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "31-50":
						switch($season){
							case "winter":
								$wrp = 3700 * 10 / 100;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 3700 * 0;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 3700 * 0;     // Water Require Percent
								$water_require = 3700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "50+":
						switch($season){
							case "winter":
								$wrp = 3700 * 10 / 100;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 3700 * 0;    // Water Require Percent
								$water_require = 3700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 3700 * 0;     // Water Require Percent
								$water_require = 3700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
				}
			}
			if($gen == 'female'){
				switch ($age) {
					case "14-18":
						switch($season){
							case "winter":
								$wrp = 2300 * 10 / 100;    // Water Require Percent
								$water_require = 2300 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 2300 * 0;    // Water Require Percent
								$water_require = 2300 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 2300 * 0;     // Water Require Percent
								$water_require = 2300 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "19-30":
						switch($season){
							case "winter":
								$wrp = 2700 * 10 / 100;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 2700 * 0;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 2700 * 0;     // Water Require Percent
								$water_require = 2700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "31-50":
						switch($season){
							case "winter":
								$wrp = 2700 * 10 / 100;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 2700 * 0;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 2700 * 0;     // Water Require Percent
								$water_require = 2700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
					case "50+":
						switch($season){
							case "winter":
								$wrp = 2700 * 10 / 100;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "normal":
								$wrp = 2700 * 0;    // Water Require Percent
								$water_require = 2700 - $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
							case "summer":
								$wrp = 2700 * 0;     // Water Require Percent
								$water_require = 2700 + $wrp;
								switch($activity){
									case "lightly-active":
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "moderately-active":
										$process2  = $water_require * 10 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
									case "very-active":
										$process2  = $water_require * 20 / 100;
                                		$water_require = $water_require + $process2;
										$water_require = round( ($water_require/1000), 1 ); 
									break;
								}
							break;
						}
					break;
				}
			}
		}
		if($fbmi > 25 ){
			$water_require = (($weight * 2.20462 ) * 2/3) * 29.5735;
			$water_require  =  $water_require /1000;
			switch($season){
				case "winter":
					$wrp =  $water_require * 10 /100 ;    //water require percent            
                    $water_require = $water_require - $wrp;
					switch($activity){
						case "moderately-active":
							$wrp =  $water_require * 10 /100 ;             
							$water_require = $water_require + $wrp;
						break;
						case "very-active":                                
							$wrp =  $water_require * 20 /100 ;             
							$water_require = $water_require + $wrp;
						break;
					}
				break;
				case "normal":
					$wrp =  $water_require * 10 /100 ;    //water require percent            
                    $water_require = $water_require - $wrp;
					switch($activity){
						case "moderately-active":
							$wrp =  $water_require * 10 /100 ;             
							$water_require = $water_require + $wrp;
						break;
						case "very-active":                                
							$wrp =  $water_require * 20 /100 ;             
							$water_require = $water_require + $wrp;
						break;
					}
				break;
			}
			$water_require = round($water_require, 1);
		}
		$water_require = '<span>'.esc_html__("You have to drink ","fc").esc_html($water_require ).esc_html__("Ltr. per day","fc").'</span>';
		$data = array('water_require' => $water_require);
		echo json_encode($data);
		wp_die();
	}
	public function fc_convert_cmtofoot(){
		$h_cm = '0';
		if(!empty($_POST['height'])){
			$h_cm = $_POST['height'];
		}
		$length = $h_cm/2.54;
		$feet = floor( $length / 12 );
		$inch = $length - 12 * $feet ;
		$inch = round($inch, 0);
		$data = array('feet' => $feet, 'inch' => $inch);
		echo json_encode($data);
		wp_die();
	}
	public function fc_convert_foottocm(){
		$h_foot = $h_inch = '0';
		if(!empty($_POST['h_foot'])){
			$h_foot = $_POST['h_foot'];
		}
		if(!empty($_POST['h_inch'])){
			$h_inch = $_POST['h_inch'];
		}
		$heightinch = $h_foot * '12';
		$totalheight = $heightinch + $h_inch;
		$heightcm = $totalheight * ('2.54');
		$fheight = round($heightcm, 0);
		$data = array('fheight' => $fheight);
		echo json_encode($data);
		wp_die();
	}
	public function fc_convert_kgtoibs(){
		 $ibsweight = $weightkg = '0';
		 if(!empty($_POST['weightkg'])){
		 	$weightkg = $_POST['weightkg'];
		 }
		 $ibsweight = $weightkg * '2.20462';
		 $fweight = round($ibsweight, 0);
		 $data = array('fweight' => $fweight);
		 echo json_encode($data);
		wp_die();
	}
	public function fc_convert_ibstokg(){
		$weightibs = $weightkg = '0';
		if(!empty($_POST['weightibs'])){
			$weightibs = $_POST['weightibs'];
		}
		$weightkg = $weightibs * 0.453592;
		$fweight = round($weightkg, 0);
		$data = array('fweight' => $fweight);
		echo json_encode($data);
		wp_die();
	}
	
	//Calorie Calculator
	public function fc_calorie_calculator(){
		$age = $gen = $height_cm = $weight = $goal = $activity = '';
		$age = $_POST['age'];
		$gen = $_POST['gen'];
		$height_cm = $_POST['hight_cm'];
		$weight = $_POST['weight'];
		$goal = $_POST['goal'];
		$activity = $_POST['activity'];
		
		//calculate protein
		$protien_require = 0;
		$protien_require_addon = 0;
		
		//First Step
		if( $age >=14 && $age <= 18 ){
			$protien_require = 0.9;
		}
		if( $age >=19 && $age <= 30 ){
			$protien_require = 0.8;
		}
		if( $age >=31 && $age <= 40 ){
			$protien_require = 0.9;
		}
		if( $age >=41 && $age <= 50 ){
			$protien_require = 1;
		}
		if( $age >=51 && $age <= 60 ){
			$protien_require = 1.1;
		}
		if( $age >=61 && $age <= 70 ){
			$protien_require = 1.2;
		}
		if( $age >=71 && $age <= 80 ){
			$protien_require = 1.3;
		}
		
		//Second Step check if sex is female then change other wise no change
		if( $gen == 'female' ){
			$protien_require = $protien_require - 0.1;
		}
		
		// 4th step check activity level
        switch( $activity ){
			case"1":
				$protien_require = $protien_require +  0.2;
			break;
			case"2":
				$protien_require = $protien_require + 0.5;
			break;
			case"3":
				$protien_require = $protien_require + 0.8;
			break;
		}
		// 4th step check user goal
		$bmi = '';
		$bmi = ($weight / $height_cm / $height_cm) * 10000;
		$bmi = round( $bmi ); 
		if( $bmi < 25 ){
			$protien_require_addon = 1.8;
		}
		if( $bmi >= 25 && $bmi <= 30 ){
			$protien_require_addon = 2.1;
		}
		if( $bmi >= 31 && $bmi <= 35 ){
			$protien_require_addon = 2.0;					
		}
		if( $bmi >= 36 && $bmi <= 40 ){
			$protien_require_addon = 1.9;
		}
		if( $bmi >= 41 && $bmi <= 45 ){
			$protien_require_addon = 1.7;
		}
		if( $bmi >= 46 && $bmi <= 50 ){
			$protien_require_addon = 1.5;
		}
		if( $bmi >= 51 ){
			$protien_require_addon = 1.3;
		}
		switch( $goal ){
			case"muscle-gain":
				$protien_require_addon = $protien_require_addon + 0.6;   
			break;
		}
		// Last Step
		$protien_require = ( $protien_require + $protien_require_addon ) * $weight;
		$protien_require = round( $protien_require, 2 );
		//Calculate Carb Require
		$bmr = '';
		//For men: 10 x weight (kg) + 6.25 x height (cm) – 5 x age (y) + 5 (kcal / day)
		if( $gen ==	'male' ){
			$bmr = (10 * $weight) + (6.25 * $height_cm) - (5 * $age) + 5;  			
		}
		//For women: 10 x weight (kg) + 6.25 x height (cm) – 5 x age (y) -161 (kcal / day)
		if( $gen == 'female' ){
			$bmr = (10 * $weight) + (6.25 * $height_cm) - (5 * $age) - 161;
		}
		switch( $activity ){
			case"0":
				$bmr = $bmr * 1.2;
			break;
			case"1":
				$bmr = $bmr * 1.375;
			break;
			case"2":
				$bmr = $bmr * 1.550;
			break;
			case"3":
				$bmr = $bmr * 1.725;
			break;
			case"4":
				$bmr = $bmr * 1.9;
			break;
		}
		
		switch( $goal ){
			case"fat-loss":
				$loss =  $bmr * (10/100) ;
				$bmr = $bmr - $loss;
			break;
			case"muscle-gain":
				$bmr = $bmr + 500;   
			break;
			
		}
		
		if( $height_cm != '' && $age != '' && $weight != '' ){
			$bmr = round( $bmr ); 
		}
		
		//Fat Calculator
		$bmi = '';
		$bmi = ( $weight / $height_cm / $height_cm ) * 10000;
		$bfp = '';
		
		if( $age > 18 ){
			if( $gen == 'male' ){
				$bfp = 1.20 * $bmi + 0.23 * $age - 16.2;
			}
			if( $gen == 'female' ){
				$bfp = 1.20 * $bmi + 0.23 * $age - 5.4;
			}
		}
		else{
			if( $gen == 'male' ){
				$bfp = 1.51 * $bmi - 0.70 * $age - 2.2;  
			}
			if( $gen == 'female' ){
				$bfp = 1.51 * $bmi - 0.70 * $age + 1.4;
			}
		}
		
		if( $height_cm != '' && $age != '' && $weight != '' ){
			$bfp = round( $bfp ); 
		}
		$data = '';
		$data = '<span><span>'.esc_html__("Your body's protein requirment is: ","fc").'<span class="cal-protien">'.esc_html($protien_require).esc_html__(" gram/day","fc").'</span></span>
				 <span>'.esc_html__("Your body's calorie requirment is: ","fc").'<span class="cal-bmr">'.esc_html($bmr).esc_html__(" calories/day","fc").'</span></span>  
				 <span>'.esc_html__("Your body's fat is: ","fc").'<span class="cal-bfp">'.esc_html($bfp).esc_html__("%","fc").'</span></span></span>';
				 
		$data = array('status'=>'success','protien_require' => $protien_require,'fat'=>$bfp,'carb'=>$bmr, 'data' => $data);
		echo json_encode($data);
		wp_die();
	}
	
	public function fc_walkdistance_cal(){
	    $age = $gen = $height = $weight = $mwd6 = $activity = '';
		$age = $_POST['age'];
		$gen = $_POST['gen'];
		$height = $_POST['height'];
		$weight = $_POST['weight'];
		
		if($gen == 'male'){
		    $mwd6 = (7.57 * $height) - (5.02 * $age) - (1.76 * $weight) - 309;
		}
		else{
		    $mwd6 = (2.11 * $height) - (2.29 * $weight) - (5.78 * $age) + 667;
		}
		
		$round_mwd6 = round( $mwd6 ); 
		if($gen == 'male'){
		    $mwd6_lower = $round_mwd6 - 153;
		}
		else{
		    $mwd6_lower = $round_mwd6 - 139;
		}
		
		$data = array('status'=>'success','mwd6' => $round_mwd6,'mwd6_lower'=>$mwd6_lower);
		echo json_encode($data);
	    wp_die();
	}
	
	public function fc_bloodtype_cal(){
	    $mother_btype = $mother_rh = $father_btype = $father_rh = '';
	    $mother_btype = $_POST['mother_btype'];
	    $mother_rh = $_POST['mother_rh'];
	    $father_btype = $_POST['father_btype'];
	    $father_rh = $_POST['father_rh'];
	    if( ($mother_rh == 'rh+'  && $father_rh == 'rh+') ){
	        $rh_minus = '6.25';
	        $rh_plus = '93.75';
	    }
	    elseif( ($mother_rh == 'rh-'  && $father_rh == 'rh-') ){
	        $rh_minus = '100';
	        $rh_plus = '0';
	    }
	    elseif( ($mother_rh == 'rh-'  && $father_rh == 'rh+') || ($mother_rh == 'rh+'  && $father_rh == 'rh-')){
	        $rh_minus = '25';
	        $rh_plus = '75';
	    }
	    if($mother_btype == 'b' && $father_btype == 'b'){
	       $data = array('status'=>'success','a' => '0','b'=>'93.75','ab'=>'0','o'=>'6.25','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'b' && $father_btype == 'a') || ($mother_btype == 'a' && $father_btype == 'b')){
	        $data = array('status'=>'success','a' => '18.75','b'=>'18.75','ab'=>'56.25','o'=>'6.25','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'b' && $father_btype == 'ab') || ($mother_btype == 'ab' && $father_btype == 'b')){
	        $data = array('status'=>'success','a' => '12.5','b'=>'50','ab'=>'37.5','o'=>'0','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'b' && $father_btype == 'o') || ($mother_btype == 'o' && $father_btype == 'b')){
	        $data = array('status'=>'success','a' => '0','b'=>'75','ab'=>'0','o'=>'25','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif($mother_btype == 'o' && $father_btype == 'o'){
	        $data = array('status'=>'success','a' => '0','b'=>'0','ab'=>'0','o'=>'100','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif($mother_btype == 'ab' && $father_btype == 'ab'){
	        $data = array('status'=>'success','a' => '25','b'=>'25','ab'=>'50','o'=>'0','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif($mother_btype == 'a' && $father_btype == 'a'){
	        $data = array('status'=>'success','a' => '93.75','b'=>'0','ab'=>'0','o'=>'6.25','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'a' && $father_btype == 'o') || ($mother_btype == 'o' && $father_btype == 'a')){
	        $data = array('status'=>'success','a' => '75','b'=>'0','ab'=>'0','o'=>'25','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'ab' && $father_btype == 'o') || ($mother_btype == 'o' && $father_btype == 'ab')){
	        $data = array('status'=>'success','a' => '50','b'=>'50','ab'=>'0','o'=>'0','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    elseif(($mother_btype == 'ab' && $father_btype == 'a') || ($mother_btype == 'a' && $father_btype == 'ab')){
	        $data = array('status'=>'success','a' => '50','b'=>'12.5','ab'=>'37.5','o'=>'0','rh_minus'=>$rh_minus,'rh_plus'=>$rh_plus);
	    }
	    echo json_encode($data);
	    wp_die();
	}
	
	/**
	 * Create custom page template for social sharing
	 */
	public function fc_page_template( $page_template ){
		require plugin_dir_path( __FILE__ ) . '/fc-page-template.php'; 
	}
	
	public function fc_chatbot_display(){
		$api = get_option('fc_chatbotdata');
		if(!empty($api['chatbot_en'])){
			wp_enqueue_style( 'plugin-fonts' );
			wp_enqueue_style( 'fc' );
			wp_enqueue_script( 'apexcharts' );
			wp_enqueue_script( 'chart-plugin' );
			wp_enqueue_script( 'fc' );
			wp_enqueue_script( 'jspdf' );
			wp_enqueue_script( 'html2canvas' );
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/fc-openapi-chatboat.php';
		}
	}
	
	/**
	 * Fitness Chatbot Option Ajax
	 */
    public function fc_chatboat_option_ajax(){
		$api = get_option('fc_chatbotdata');
        $openai_api_save = '';
		$user_key = '';
	
		if(!empty($api['chatbot_openai'])):
			$openai_api_save = $api['chatbot_openai'];
			$user_key ='yes';
		endif;
        $getMaxTokens = 1000;
		if(!empty($general_api['max_tokens'])):
			$getMaxTokens = $general_api['max_tokens'];
		endif; 
		$getTemperature =0.5;
		if(!empty($general_api['temperature'])):
			$getTemperature = $general_api['temperature'];
		endif;
		$model_option = 'gpt-3.5-turbo-instruct';
		if(!empty($general_api['model_option'])):
			$model_option = $general_api['model_option'];
		endif;
		$presence_penalty = 0.01;
		if(!empty($general_api['presence_penalty'])): 
			$presence_penalty = $general_api['presence_penalty'];
		endif;
		$frequency_penalty = 0.01;
		if(!empty($general_api['frequency_penalty'])): 
			$frequency_penalty = $general_api['frequency_penalty'];
		endif;
		$best_of = 1;
		if(!empty($general_api['best_of'])): 
			$best_of = $general_api['best_of'];
		endif;
		$top_p = 0.01;
		if(!empty($general_api['top_p'])): 
			$top_p = $general_api['top_p'];
		endif;
		$chat_get_value = '';
		if(!empty($_POST['chat_get_value'])):
			$chat_get_value = sanitize_text_field($_POST['chat_get_value']);
		endif;
	    $header = array(
		   'Authorization: Bearer '.$openai_api_save,
		   'Content-type: application/json; charset=utf-8',
		 );
		$params = json_encode(array(
		   'prompt' => $chat_get_value,
		   'model'	 => 'gpt-3.5-turbo-instruct',
		   'temperature' => (float)$getTemperature,
		   'max_tokens' => (float)$getMaxTokens,
		));
		$curl = curl_init('https://api.openai.com/v1/completions');
		$options = array(
			CURLOPT_POST => true,
			CURLOPT_HTTPHEADER =>$header,
			CURLOPT_POSTFIELDS => $params,
			CURLOPT_RETURNTRANSFER => true,
		);
		curl_setopt_array($curl, $options);
		$response = curl_exec($curl);
		$httpcode = curl_getinfo($curl, CURLINFO_RESPONSE_CODE);
		if(200 == $httpcode){
			$json_array = json_decode($response, true);
			$choices = $json_array['choices'];
			$postContent = $choices[0]["text"];
			$result_data = array(
				'status'=>$httpcode,
				'content_data'=> trim($postContent),
				'message' => esc_html__('Successfully',"fc")
				);
		}else{
			if(!empty($user_key)){
				$result_data = array(
				  'status'=>$httpcode,
				  'user_key'=>$user_key,
				  'message' => esc_html__("Something went to wrong!","fc")
				);
			}else{
				$result_data = array(
				  'status'=>$httpcode,
				  'user_key'=>$user_key,
				  'message' => esc_html__("Kindly provide your Opanai API key.","fc")
				);
			}
			/**
			 * Api key Update
			 */  
			if(empty($general_api['api_key'])){
				if($httpcode == 429){
				  $remot_hit = $this->gpt_remote_api_update();
				  if($remot_hit){
				    $this->gptpower_chatbot_option_ajax();
				   }
                }
			}
		}
		echo json_encode($result_data);
		wp_die();	 
	}
	
	/**
	 * Diet chart ajax
	 */
	public function fc_diet_chart_ajax(){
		$calory = $country = $cat = '';
		if(!empty($_POST['calory'])){
			$calory = $_POST['calory'];
			if(!empty($_POST['country'])){
				$country = $_POST['country'];
			}else{
				$country = esc_html__('India', 'fc');
			}
			if(!empty($_POST['category'])){
				$cat = $_POST['category'];
			}else{
				$cat = esc_html__('veg', 'fc');
			}
			
			$api = get_option('fc_chatbotdata');
			if(!empty($api['chatbot_openai'])){
				$openai_api = $api['chatbot_openai'];
				$chat_get_value = 'Give the full one-week sample meal plan for '.$cat.' in '.$country.' if I need to consume '.$calory.' calories per day in html formate';
				$getTemperature = 0.5;
				$getMaxTokens = 1000;
				//open ai code
				 $header = array(
				   'Authorization: Bearer '.$openai_api,
				   'Content-type: application/json; charset=utf-8',
				 );
				$params = json_encode(array(
				   'prompt' => $chat_get_value,
				   'model'	 => 'gpt-3.5-turbo-instruct',
				   'temperature' => (float)$getTemperature,
				   'max_tokens' => (float)$getMaxTokens,
				));
				$curl = curl_init('https://api.openai.com/v1/completions');
				$options = array(
					CURLOPT_POST => true,
					CURLOPT_HTTPHEADER =>$header,
					CURLOPT_POSTFIELDS => $params,
					CURLOPT_RETURNTRANSFER => true,
				);
				curl_setopt_array($curl, $options);
				$response = curl_exec($curl);
				$httpcode = curl_getinfo($curl, CURLINFO_RESPONSE_CODE);
				
				if(200 == $httpcode){
					$json_array = json_decode($response, true);
					update_option('diet_data',$response);
					
					//table content start
					$diet = $json_array['choices'];
					$postContent = $diet['0']['text'];
					
					$result = array(
						'status'=>$httpcode,
						'content_data'=> $postContent,
						'message' => esc_html__('Successfully',"fc")
						);
				}else{
					$result = array(
					  'status'=>$httpcode,
					  'user_key'=>$user_key,
					  'content_data' => esc_html__("Something went to wrong!","fc")
					);
				}
				
			}else{
				$result = array(
				  'status'=>'error',
				  'content_data' => esc_html__("Please enter openai api key for result.","fc")
				);
			}
			
		}else{
			$result = array(
			  'status'=>'error',
			  'content_data' => esc_html__("Please enter calory value first.","fc")
			);
		}
		echo json_encode($result);
		wp_die();
	}
	
	public function fc_custom_css(){
		require_once( plugin_dir_path( dirname( __FILE__ ) ) . 'public/css/color-picker-css.php' );
	}
}
